@@ -57,6 +57,7 @@ import org.apache.catalina.connector.Response;
 import org.apache.catalina.filters.CorsFilter;
 import org.apache.catalina.filters.RemoteIpFilter;
 import org.apache.catalina.realm.GenericPrincipal;
+import org.apache.catalina.util.FilterUtil;
 import org.apache.catalina.util.SessionIdGeneratorBase;
 import org.apache.catalina.util.StandardSessionIdGenerator;
 import org.apache.catalina.valves.RemoteIpValve;
@@ -441,8 +442,8 @@ public abstract class AuthenticatorBase extends ValveBase implements Authenticat
     @Override
     public void invoke(Request request, Response response) throws IOException, ServletException {
 
-        if (log.isDebugEnabled()) {
-            log.debug("Security checking request " + request.getMethod() + " " + request.getRequestURI());
+        if (log.isTraceEnabled()) {
+            log.trace("Security checking request " + request.getMethod() + " " + request.getRequestURI());
         }
 
         // Have we got a cached authenticated Principal to record?
@@ -453,8 +454,8 @@ public abstract class AuthenticatorBase extends ValveBase implements Authenticat
                 if (session != null) {
                     principal = session.getPrincipal();
                     if (principal != null) {
-                        if (log.isDebugEnabled()) {
-                            log.debug("We have cached auth type " + session.getAuthType() + " for principal " +
+                        if (log.isTraceEnabled()) {
+                            log.trace("We have cached auth type " + session.getAuthType() + " for principal " +
                                     principal);
                         }
                         request.setAuthType(session.getAuthType());
@@ -476,8 +477,8 @@ public abstract class AuthenticatorBase extends ValveBase implements Authenticat
         }
 
         if (constraints == null && !context.getPreemptiveAuthentication() && !authRequired) {
-            if (log.isDebugEnabled()) {
-                log.debug("Not subject to any constraint");
+            if (log.isTraceEnabled()) {
+                log.trace("Not subject to any constraint");
             }
             getNext().invoke(request, response);
             return;
@@ -498,12 +499,12 @@ public abstract class AuthenticatorBase extends ValveBase implements Authenticat
 
         if (constraints != null) {
             // Enforce any user data constraint for this security constraint
-            if (log.isDebugEnabled()) {
-                log.debug("Calling hasUserDataPermission()");
+            if (log.isTraceEnabled()) {
+                log.trace("Calling hasUserDataPermission()");
             }
             if (!realm.hasUserDataPermission(request, response, constraints)) {
                 if (log.isDebugEnabled()) {
-                    log.debug("Failed hasUserDataPermission() test");
+                    log.debug(sm.getString("authenticator.userDataPermissionFail"));
                 }
                 /*
                  * ASSERT: Authenticator already set the appropriate HTTP status code, so we do not have to do anything
@@ -542,15 +543,15 @@ public abstract class AuthenticatorBase extends ValveBase implements Authenticat
 
         if ((authRequired || constraints != null) && allowCorsPreflightBypass(request)) {
             if (log.isDebugEnabled()) {
-                log.debug("CORS Preflight request bypassing authentication");
+                log.debug(sm.getString("authenticator.corsBypass"));
             }
             getNext().invoke(request, response);
             return;
         }
 
         if (authRequired) {
-            if (log.isDebugEnabled()) {
-                log.debug("Calling authenticate()");
+            if (log.isTraceEnabled()) {
+                log.trace("Calling authenticate()");
             }
 
             if (jaspicProvider != null) {
@@ -563,7 +564,7 @@ public abstract class AuthenticatorBase extends ValveBase implements Authenticat
             if (jaspicProvider == null && !doAuthenticate(request, response) ||
                     jaspicProvider != null && !authenticateJaspic(request, response, jaspicState, false)) {
                 if (log.isDebugEnabled()) {
-                    log.debug("Failed authenticate() test");
+                    log.debug(sm.getString("authenticator.authenticationFail"));
                 }
                 /*
                  * ASSERT: Authenticator already set the appropriate HTTP status code, so we do not have to do anything
@@ -575,12 +576,12 @@ public abstract class AuthenticatorBase extends ValveBase implements Authenticat
         }
 
         if (constraints != null) {
-            if (log.isDebugEnabled()) {
-                log.debug("Calling accessControl()");
+            if (log.isTraceEnabled()) {
+                log.trace("Calling accessControl()");
             }
             if (!realm.hasResourcePermission(request, response, constraints, this.context)) {
                 if (log.isDebugEnabled()) {
-                    log.debug("Failed accessControl() test");
+                    log.debug(sm.getString("authenticator.userPermissionFail", request.getUserPrincipal().getName()));
                 }
                 /*
                  * ASSERT: AccessControl method has already set the appropriate HTTP status code, so we do not have to
@@ -591,8 +592,8 @@ public abstract class AuthenticatorBase extends ValveBase implements Authenticat
         }
 
         // Any and all specified constraints have been satisfied
-        if (log.isDebugEnabled()) {
-            log.debug("Successfully passed all security constraints");
+        if (log.isTraceEnabled()) {
+            log.trace("Successfully passed all security constraints");
         }
         getNext().invoke(request, response);
 
@@ -628,12 +629,9 @@ public abstract class AuthenticatorBase extends ValveBase implements Authenticat
                                         for (FilterMap filterMap : context.findFilterMaps()) {
                                             if (filterMap.getFilterName().equals(filterDef.getFilterName())) {
                                                 if ((filterMap.getDispatcherMapping() & FilterMap.REQUEST) > 0) {
-                                                    for (String urlPattern : filterMap.getURLPatterns()) {
-                                                        if ("/*".equals(urlPattern)) {
-                                                            allowBypass = true;
-                                                            // No need to check other patterns
-                                                            break;
-                                                        }
+                                                    String requestPath = FilterUtil.getRequestPath(request);
+                                                    if (FilterUtil.matchFiltersURL(filterMap, requestPath)) {
+                                                        allowBypass = true;
                                                     }
                                                 }
                                                 // Found mappings for CORS filter.
@@ -805,6 +803,8 @@ public abstract class AuthenticatorBase extends ValveBase implements Authenticat
             authStatus = state.serverAuthContext.validateRequest(state.messageInfo, client, null);
         } catch (AuthException e) {
             log.debug(sm.getString("authenticator.loginFail"), e);
+            // Need to explicitly set the return code as the ServerAuthContext may not have done.
+            response.setStatus(HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
             return false;
         }
 
@@ -813,8 +813,8 @@ public abstract class AuthenticatorBase extends ValveBase implements Authenticat
 
         if (authStatus == AuthStatus.SUCCESS) {
             GenericPrincipal principal = getPrincipal(client);
-            if (log.isDebugEnabled()) {
-                log.debug("Authenticated user: " + principal);
+            if (log.isTraceEnabled()) {
+                log.trace("Authenticated user: " + principal);
             }
             if (principal == null) {
                 request.setUserPrincipal(null);
@@ -975,8 +975,8 @@ public abstract class AuthenticatorBase extends ValveBase implements Authenticat
             associate(ssoId, request.getSessionInternal(true));
 
             if (log.isDebugEnabled()) {
-                log.debug("Reauthenticated cached principal '" + request.getUserPrincipal().getName() +
-                        "' with auth type '" + request.getAuthType() + "'");
+                log.debug(sm.getString("authenticator.reauthentication", request.getUserPrincipal().getName(),
+                        request.getAuthType()));
             }
         }
 
@@ -1018,7 +1018,7 @@ public abstract class AuthenticatorBase extends ValveBase implements Authenticat
 
         if (log.isDebugEnabled()) {
             String name = (principal == null) ? "none" : principal.getName();
-            log.debug("Authenticated '" + name + "' with type '" + authType + "'");
+            log.debug(sm.getString("authenticator.authentication", name, authType));
         }
 
         // Cache the authentication information in our request
@@ -1078,13 +1078,16 @@ public abstract class AuthenticatorBase extends ValveBase implements Authenticat
                 cookie.setDomain(ssoDomain);
             }
 
-            // Configure httpOnly on SSO cookie using same rules as session
-            // cookies
+            // Configure httpOnly on SSO cookie using same rules as session cookies
             if (request.getServletContext().getSessionCookieConfig().isHttpOnly() ||
                     request.getContext().getUseHttpOnly()) {
                 cookie.setHttpOnly(true);
             }
 
+            // Configure Partitioned on SSO cookie using same rules as session cookies
+            cookie.setAttribute(Constants.COOKIE_PARTITIONED_ATTR,
+                    Boolean.toString(request.getContext().getUsePartitioned()));
+
             response.addCookie(cookie);
 
             // Register this principal with our SSO valve
@@ -1197,7 +1200,7 @@ public abstract class AuthenticatorBase extends ValveBase implements Authenticat
 
 
     @Override
-    protected synchronized void startInternal() throws LifecycleException {
+    protected void startInternal() throws LifecycleException {
         ServletContext servletContext = context.getServletContext();
         jaspicAppContextID = servletContext.getVirtualServerName() + " " + servletContext.getContextPath();
 
@@ -1218,9 +1221,9 @@ public abstract class AuthenticatorBase extends ValveBase implements Authenticat
         }
         if (log.isDebugEnabled()) {
             if (sso != null) {
-                log.debug("Found SingleSignOn Valve at " + sso);
+                log.debug(sm.getString("authenticator.sso", sso));
             } else {
-                log.debug("No SingleSignOn Valve is present");
+                log.trace("No SingleSignOn Valve is present");
             }
         }
 
@@ -1234,7 +1237,7 @@ public abstract class AuthenticatorBase extends ValveBase implements Authenticat
 
 
     @Override
-    protected synchronized void stopInternal() throws LifecycleException {
+    protected void stopInternal() throws LifecycleException {
         super.stopInternal();
         sso = null;
     }
