@@ -60,7 +60,7 @@ public final class SavedRequest implements Serializable {
      * The set of Headers associated with this Request. Each key is a header name, while the value is a List containing
      * one or more actual values for this header. The values are returned as an Iterator when you ask for them.
      */
-    private final Map<String, List<String>> headers = new HashMap<>();
+    private final Map<String,List<String>> headers = new HashMap<>();
 
     public void addHeader(String name, String value) {
         headers.computeIfAbsent(name, k -> new ArrayList<>()).add(value);
@@ -163,6 +163,7 @@ public final class SavedRequest implements Serializable {
         this.body = body;
     }
 
+
     /**
      * The content type of the request, used if this is a POST.
      */
@@ -175,4 +176,18 @@ public final class SavedRequest implements Serializable {
     public void setContentType(String contentType) {
         this.contentType = contentType;
     }
+
+
+    /**
+     * The original maxInactiveInterval for the session.
+     */
+    private int originalMaxInactiveInterval = -1;
+
+    public int getOriginalMaxInactiveInterval() {
+        return originalMaxInactiveInterval;
+    }
+
+    public void setOriginalMaxInactiveInterval(int originalMaxInactiveInterval) {
+        this.originalMaxInactiveInterval = originalMaxInactiveInterval;
+    }
 }
