@@ -24,14 +24,14 @@ import java.util.Set;
 import java.util.function.Predicate;
 import java.util.regex.Pattern;
 
-import javax.servlet.FilterChain;
-import javax.servlet.FilterConfig;
-import javax.servlet.ServletException;
-import javax.servlet.ServletRequest;
-import javax.servlet.ServletResponse;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
-import javax.servlet.http.HttpSession;
+import jakarta.servlet.FilterChain;
+import jakarta.servlet.FilterConfig;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.ServletRequest;
+import jakarta.servlet.ServletResponse;
+import jakarta.servlet.http.HttpServletRequest;
+import jakarta.servlet.http.HttpServletResponse;
+import jakarta.servlet.http.HttpSession;
 
 /**
  * Provides basic CSRF protection for REST APIs. The filter assumes that the clients have adapted the transfer of the
@@ -85,8 +85,9 @@ public class RestCsrfPreventionFilter extends CsrfPreventionFilterBase {
     private static final Predicate<String> nonModifyingMethods =
             m -> Objects.nonNull(m) && NON_MODIFYING_METHODS_PATTERN.matcher(m).matches();
 
-    private final Set<String> pathsAcceptingParams = new HashSet<>();
-    private static final String pathsDelimiter = ",";
+    private Set<String> pathsAcceptingParams = new HashSet<>();
+
+    private String pathsDelimiter = ",";
 
     @Override
     public void init(FilterConfig filterConfig) throws ServletException {
@@ -109,10 +110,13 @@ public class RestCsrfPreventionFilter extends CsrfPreventionFilterBase {
             }
 
             RestCsrfPreventionStrategy strategy;
-            if (mType == MethodType.NON_MODIFYING_METHOD) {
-                strategy = new FetchRequest();
-            } else {
-                strategy = new StateChangingRequest();
+            switch (mType) {
+                case NON_MODIFYING_METHOD:
+                    strategy = new FetchRequest();
+                    break;
+                default:
+                    strategy = new StateChangingRequest();
+                    break;
             }
 
             if (!strategy.apply((HttpServletRequest) request, (HttpServletResponse) response)) {
