@@ -33,8 +33,7 @@ import org.apache.tomcat.util.res.StringManager;
 /*
  * Sender to proxies using multicast socket.
  */
-public class TcpSender
-    implements Sender {
+public class TcpSender implements Sender {
 
     private static final Log log = LogFactory.getLog(HeartbeatListener.class);
     private static final StringManager sm = StringManager.getManager(TcpSender.class);
@@ -71,7 +70,7 @@ public class TcpSender
             proxies[i] = new Proxy();
             proxies[i].port = Integer.parseInt(token.substring(pos + 1));
             try {
-                 proxies[i].address = InetAddress.getByName(token.substring(0, pos));
+                proxies[i].address = InetAddress.getByName(token.substring(0, pos));
             } catch (Exception e) {
                 throw new Exception(sm.getString("tcpSender.invalidProxyList"));
             }
@@ -96,7 +95,7 @@ public class TcpSender
                 try {
                     if (config.getHost() != null) {
                         connections[i] = new Socket();
-                        InetAddress addr =  InetAddress.getByName(config.getHost());
+                        InetAddress addr = InetAddress.getByName(config.getHost());
                         InetSocketAddress addrs = new InetSocketAddress(addr, 0);
                         connections[i].setReuseAddress(true);
                         connections[i].bind(addrs);
@@ -112,8 +111,7 @@ public class TcpSender
                     close(i);
                 }
             }
-            if (connections[i] == null)
-             {
+            if (connections[i] == null) {
                 continue; // try next proxy in the list
             }
             BufferedWriter writer = connectionWriters[i];
@@ -131,8 +129,7 @@ public class TcpSender
                 log.error(sm.getString("tcpSender.sendFailed"), ex);
                 close(i);
             }
-            if (connections[i] == null)
-             {
+            if (connections[i] == null) {
                 continue; // try next proxy in the list
             }
 
@@ -143,7 +140,8 @@ public class TcpSender
                 close(i);
                 continue;
             } else {
-                responseStatus = responseStatus.substring(responseStatus.indexOf(' ') + 1, responseStatus.indexOf(' ', responseStatus.indexOf(' ') + 1));
+                responseStatus = responseStatus.substring(responseStatus.indexOf(' ') + 1,
+                        responseStatus.indexOf(' ', responseStatus.indexOf(' ') + 1));
                 int status = Integer.parseInt(responseStatus);
                 if (status != 200) {
                     log.error(sm.getString("tcpSender.responseErrorCode", Integer.valueOf(status)));
@@ -175,7 +173,7 @@ public class TcpSender
                         } else {
                             contentLength -= n;
                         }
-                   }
+                    }
                 }
             }
 
@@ -186,6 +184,7 @@ public class TcpSender
 
     /**
      * Close connection.
+     *
      * @param i The index of the connection that will be closed
      */
     protected void close(int i) {
