@@ -207,8 +207,8 @@ public class FarmWarDeployer extends ClusterListener implements ClusterDeployer,
         try {
             if (msg instanceof FileMessage) {
                 FileMessage fmsg = (FileMessage) msg;
-                if (log.isDebugEnabled()) {
-                    log.debug(sm.getString("farmWarDeployer.msgRxDeploy", fmsg.getContextName(), fmsg.getFileName()));
+                if (log.isTraceEnabled()) {
+                    log.trace(sm.getString("farmWarDeployer.msgRxDeploy", fmsg.getContextName(), fmsg.getFileName()));
                 }
                 FileMessageFactory factory = getFactory(fmsg);
                 // TODO correct second try after app is in service!
@@ -232,8 +232,8 @@ public class FarmWarDeployer extends ClusterListener implements ClusterDeployer,
                                 removeServiced(contextName);
                             }
                             check(contextName);
-                            if (log.isDebugEnabled()) {
-                                log.debug(sm.getString("farmWarDeployer.deployEnd", contextName));
+                            if (log.isTraceEnabled()) {
+                                log.trace(sm.getString("farmWarDeployer.deployEnd", contextName));
                             }
                         } else {
                             log.error(sm.getString("farmWarDeployer.servicingDeploy", contextName, name));
@@ -248,8 +248,8 @@ public class FarmWarDeployer extends ClusterListener implements ClusterDeployer,
                 try {
                     UndeployMessage umsg = (UndeployMessage) msg;
                     String contextName = umsg.getContextName();
-                    if (log.isDebugEnabled()) {
-                        log.debug(sm.getString("farmWarDeployer.msgRxUndeploy", contextName));
+                    if (log.isTraceEnabled()) {
+                        log.trace(sm.getString("farmWarDeployer.msgRxUndeploy", contextName));
                     }
                     if (tryAddServiced(contextName)) {
                         try {
@@ -257,8 +257,8 @@ public class FarmWarDeployer extends ClusterListener implements ClusterDeployer,
                         } finally {
                             removeServiced(contextName);
                         }
-                        if (log.isDebugEnabled()) {
-                            log.debug(sm.getString("farmWarDeployer.undeployEnd", contextName));
+                        if (log.isTraceEnabled()) {
+                            log.trace(sm.getString("farmWarDeployer.undeployEnd", contextName));
                         }
                     } else {
                         log.error(sm.getString("farmWarDeployer.servicingUndeploy", contextName));
@@ -303,13 +303,9 @@ public class FarmWarDeployer extends ClusterListener implements ClusterDeployer,
     }
 
     /**
-     * Before the cluster invokes messageReceived the cluster will ask the receiver to accept or decline the message, In
-     * the future, when messages get big, the accept method will only take a message header
-     *
-     * @param msg ClusterMessage
-     *
-     * @return boolean - returns true to indicate that messageReceived should be invoked. If false is returned, the
-     *             messageReceived method will not be invoked.
+     * {@inheritDoc}
+     * <p>
+     * This listener accepts only FileMessage or UndeployMessage.
      */
     @Override
     public boolean accept(ClusterMessage msg) {
@@ -340,21 +336,21 @@ public class FarmWarDeployer extends ClusterListener implements ClusterDeployer,
         Member localMember = getCluster().getLocalMember();
         FileMessageFactory factory = FileMessageFactory.getInstance(webapp, false);
         FileMessage msg = new FileMessage(localMember, webapp.getName(), contextName);
-        if (log.isDebugEnabled()) {
-            log.debug(sm.getString("farmWarDeployer.sendStart", contextName, webapp));
+        if (log.isTraceEnabled()) {
+            log.trace(sm.getString("farmWarDeployer.sendStart", contextName, webapp));
         }
         msg = factory.readMessage(msg);
         while (msg != null) {
             for (Member member : members) {
-                if (log.isDebugEnabled()) {
-                    log.debug(sm.getString("farmWarDeployer.sendFragment", contextName, webapp, member));
+                if (log.isTraceEnabled()) {
+                    log.trace(sm.getString("farmWarDeployer.sendFragment", contextName, webapp, member));
                 }
                 getCluster().send(msg, member);
             }
             msg = factory.readMessage(msg);
         }
-        if (log.isDebugEnabled()) {
-            log.debug(sm.getString("farmWarDeployer.sendEnd", contextName, webapp));
+        if (log.isTraceEnabled()) {
+            log.trace(sm.getString("farmWarDeployer.sendEnd", contextName, webapp));
         }
     }
 
@@ -381,8 +377,8 @@ public class FarmWarDeployer extends ClusterListener implements ClusterDeployer,
             Member localMember = getCluster().getLocalMember();
             UndeployMessage msg = new UndeployMessage(localMember, System.currentTimeMillis(),
                     "Undeploy:" + contextName + ":" + System.currentTimeMillis(), contextName);
-            if (log.isDebugEnabled()) {
-                log.debug(sm.getString("farmWarDeployer.removeTxMsg", contextName));
+            if (log.isTraceEnabled()) {
+                log.trace(sm.getString("farmWarDeployer.removeTxMsg", contextName));
             }
             cluster.send(msg);
         }
@@ -407,11 +403,6 @@ public class FarmWarDeployer extends ClusterListener implements ClusterDeployer,
 
     }
 
-    /**
-     * Modification from watchDir war detected!
-     *
-     * @see org.apache.catalina.ha.deploy.FileChangeListener#fileModified(File)
-     */
     @Override
     public void fileModified(File newWar) {
         try {
@@ -443,11 +434,6 @@ public class FarmWarDeployer extends ClusterListener implements ClusterDeployer,
         }
     }
 
-    /**
-     * War remove from watchDir
-     *
-     * @see org.apache.catalina.ha.deploy.FileChangeListener#fileRemoved(File)
-     */
     @Override
     public void fileRemoved(File removeWar) {
         try {
@@ -586,16 +572,6 @@ public class FarmWarDeployer extends ClusterListener implements ClusterDeployer,
     }
 
     /*--Instance Getters/Setters--------------------------------*/
-    @Override
-    public boolean equals(Object listener) {
-        return super.equals(listener);
-    }
-
-    @Override
-    public int hashCode() {
-        return super.hashCode();
-    }
-
     public String getDeployDir() {
         return deployDir;
     }
