@@ -18,7 +18,10 @@ package org.apache.catalina.realm;
 
 import java.beans.PropertyChangeListener;
 import java.beans.PropertyChangeSupport;
+import java.io.BufferedReader;
+import java.io.FileReader;
 import java.io.IOException;
+import java.io.InputStreamReader;
 import java.io.UnsupportedEncodingException;
 import java.nio.charset.Charset;
 import java.nio.charset.StandardCharsets;
@@ -417,8 +420,8 @@ public abstract class RealmBase extends LifecycleMBeanBase implements Realm {
 
         String serverDigest = HexUtils.toHexString(ConcurrentMessageDigest.digest(algorithm, valueBytes));
 
-        if (log.isDebugEnabled()) {
-            log.debug("Digest : " + clientDigest + " Username:" + username + " ClientDigest:" + clientDigest +
+        if (log.isTraceEnabled()) {
+            log.trace("Digest : " + clientDigest + " Username:" + username + " ClientDigest:" + clientDigest +
                     " nonce:" + nonce + " nc:" + nc + " cnonce:" + cnonce + " qop:" + qop + " realm:" + realm +
                     "digestA2:" + digestA2 + " Server digest:" + serverDigest);
         }
@@ -439,19 +442,19 @@ public abstract class RealmBase extends LifecycleMBeanBase implements Realm {
         }
 
         // Check the validity of each certificate in the chain
-        if (log.isDebugEnabled()) {
-            log.debug("Authenticating client certificate chain");
+        if (log.isTraceEnabled()) {
+            log.trace("Authenticating client certificate chain");
         }
         if (validate) {
             for (X509Certificate cert : certs) {
-                if (log.isDebugEnabled()) {
-                    log.debug(" Checking validity for '" + cert.getSubjectX500Principal().toString() + "'");
+                if (log.isTraceEnabled()) {
+                    log.trace(" Checking validity for '" + cert.getSubjectX500Principal().toString() + "'");
                 }
                 try {
                     cert.checkValidity();
                 } catch (Exception e) {
                     if (log.isDebugEnabled()) {
-                        log.debug("  Validity exception", e);
+                        log.debug(sm.getString("realmBase.validity"), e);
                     }
                     return null;
                 }
@@ -483,13 +486,13 @@ public abstract class RealmBase extends LifecycleMBeanBase implements Realm {
                             log.warn(sm.getString("realmBase.delegatedCredentialFail", gssName), e);
                         }
                     } else {
-                        if (log.isDebugEnabled()) {
-                            log.debug(sm.getString("realmBase.credentialNotDelegated", gssName));
+                        if (log.isTraceEnabled()) {
+                            log.trace(sm.getString("realmBase.credentialNotDelegated", gssName));
                         }
                     }
                 }
 
-                return getPrincipal(gssName, gssCredential);
+                return getPrincipal(gssName, gssCredential, gssContext);
             }
         } else {
             log.error(sm.getString("realmBase.gssContextNotEstablished"));
@@ -528,8 +531,8 @@ public abstract class RealmBase extends LifecycleMBeanBase implements Realm {
         // Are there any defined security constraints?
         SecurityConstraint constraints[] = context.findConstraints();
         if (constraints == null || constraints.length == 0) {
-            if (log.isDebugEnabled()) {
-                log.debug("  No applicable constraints defined");
+            if (log.isTraceEnabled()) {
+                log.trace("  No applicable constraints defined");
             }
             return null;
         }
@@ -554,8 +557,8 @@ public abstract class RealmBase extends LifecycleMBeanBase implements Realm {
                 continue;
             }
 
-            if (log.isDebugEnabled()) {
-                log.debug("  Checking constraint '" + constraints[i] + "' against " + method + " " + uri + " --> " +
+            if (log.isTraceEnabled()) {
+                log.trace("  Checking constraint '" + constraints[i] + "' against " + method + " " + uri + " --> " +
                         constraints[i].included(uri, method));
             }
 
@@ -598,8 +601,8 @@ public abstract class RealmBase extends LifecycleMBeanBase implements Realm {
                 continue;
             }
 
-            if (log.isDebugEnabled()) {
-                log.debug("  Checking constraint '" + constraints[i] + "' against " + method + " " + uri + " --> " +
+            if (log.isTraceEnabled()) {
+                log.trace("  Checking constraint '" + constraints[i] + "' against " + method + " " + uri + " --> " +
                         constraints[i].included(uri, method));
             }
 
@@ -660,8 +663,8 @@ public abstract class RealmBase extends LifecycleMBeanBase implements Realm {
                 continue;
             }
 
-            if (log.isDebugEnabled()) {
-                log.debug("  Checking constraint '" + constraints[i] + "' against " + method + " " + uri + " --> " +
+            if (log.isTraceEnabled()) {
+                log.trace("  Checking constraint '" + constraints[i] + "' against " + method + " " + uri + " --> " +
                         constraints[i].included(uri, method));
             }
 
@@ -715,8 +718,8 @@ public abstract class RealmBase extends LifecycleMBeanBase implements Realm {
                 continue;
             }
 
-            if (log.isDebugEnabled()) {
-                log.debug("  Checking constraint '" + constraints[i] + "' against " + method + " " + uri + " --> " +
+            if (log.isTraceEnabled()) {
+                log.trace("  Checking constraint '" + constraints[i] + "' against " + method + " " + uri + " --> " +
                         constraints[i].included(uri, method));
             }
 
@@ -747,8 +750,8 @@ public abstract class RealmBase extends LifecycleMBeanBase implements Realm {
 
         if (results == null) {
             // No applicable security constraint was found
-            if (log.isDebugEnabled()) {
-                log.debug("  No applicable constraint located");
+            if (log.isTraceEnabled()) {
+                log.trace("  No applicable constraint located");
             }
         }
         return resultsToArray(results);
@@ -790,50 +793,50 @@ public abstract class RealmBase extends LifecycleMBeanBase implements Realm {
                 roles = new String[0];
             }
 
-            if (log.isDebugEnabled()) {
-                log.debug("  Checking roles " + principal);
+            if (log.isTraceEnabled()) {
+                log.trace("  Checking roles " + principal);
             }
 
             if (constraint.getAuthenticatedUsers() && principal != null) {
-                if (log.isDebugEnabled()) {
-                    log.debug("Passing all authenticated users");
+                if (log.isTraceEnabled()) {
+                    log.trace("Passing all authenticated users");
                 }
                 status = true;
             } else if (roles.length == 0 && !constraint.getAllRoles() && !constraint.getAuthenticatedUsers()) {
                 if (constraint.getAuthConstraint()) {
-                    if (log.isDebugEnabled()) {
-                        log.debug("No roles");
+                    if (log.isTraceEnabled()) {
+                        log.trace("No roles");
                     }
                     status = false; // No listed roles means no access at all
                     denyfromall = true;
                     break;
                 }
 
-                if (log.isDebugEnabled()) {
-                    log.debug("Passing all access");
+                if (log.isTraceEnabled()) {
+                    log.trace("Passing all access");
                 }
                 status = true;
             } else if (principal == null) {
-                if (log.isDebugEnabled()) {
-                    log.debug("  No user authenticated, cannot grant access");
+                if (log.isTraceEnabled()) {
+                    log.trace("  No user authenticated, cannot grant access");
                 }
             } else {
                 for (String role : roles) {
                     if (hasRole(request.getWrapper(), principal, role)) {
                         status = true;
-                        if (log.isDebugEnabled()) {
-                            log.debug("Role found:  " + role);
+                        if (log.isTraceEnabled()) {
+                            log.trace("Role found:  " + role);
                         }
-                    } else if (log.isDebugEnabled()) {
-                        log.debug("No role found:  " + role);
+                    } else if (log.isTraceEnabled()) {
+                        log.trace("No role found:  " + role);
                     }
                 }
             }
         }
 
         if (!denyfromall && allRolesMode != AllRolesMode.STRICT_MODE && !status && principal != null) {
-            if (log.isDebugEnabled()) {
-                log.debug("Checking for all roles mode: " + allRolesMode);
+            if (log.isTraceEnabled()) {
+                log.trace("Checking for all roles mode: " + allRolesMode);
             }
             // Check for an all roles(role-name="*")
             for (SecurityConstraint constraint : constraints) {
@@ -841,8 +844,8 @@ public abstract class RealmBase extends LifecycleMBeanBase implements Realm {
                 // If the all roles mode exists, sets
                 if (constraint.getAllRoles()) {
                     if (allRolesMode == AllRolesMode.AUTH_ONLY_MODE) {
-                        if (log.isDebugEnabled()) {
-                            log.debug("Granting access for role-name=*, auth-only");
+                        if (log.isTraceEnabled()) {
+                            log.trace("Granting access for role-name=*, auth-only");
                         }
                         status = true;
                         break;
@@ -854,8 +857,8 @@ public abstract class RealmBase extends LifecycleMBeanBase implements Realm {
                         roles = new String[0];
                     }
                     if (roles.length == 0 && allRolesMode == AllRolesMode.STRICT_AUTH_ONLY_MODE) {
-                        if (log.isDebugEnabled()) {
-                            log.debug("Granting access for role-name=*, strict auth-only");
+                        if (log.isTraceEnabled()) {
+                            log.trace("Granting access for role-name=*, strict auth-only");
                         }
                         status = true;
                         break;
@@ -897,12 +900,12 @@ public abstract class RealmBase extends LifecycleMBeanBase implements Realm {
 
         boolean result = hasRoleInternal(principal, role);
 
-        if (log.isDebugEnabled()) {
+        if (log.isTraceEnabled()) {
             String name = principal.getName();
             if (result) {
-                log.debug(sm.getString("realmBase.hasRoleSuccess", name, role));
+                log.trace(sm.getString("realmBase.hasRoleSuccess", name, role));
             } else {
-                log.debug(sm.getString("realmBase.hasRoleFailure", name, role));
+                log.trace(sm.getString("realmBase.hasRoleFailure", name, role));
             }
         }
 
@@ -972,22 +975,22 @@ public abstract class RealmBase extends LifecycleMBeanBase implements Realm {
 
         // Is there a relevant user data constraint?
         if (constraints == null || constraints.length == 0) {
-            if (log.isDebugEnabled()) {
-                log.debug("  No applicable security constraint defined");
+            if (log.isTraceEnabled()) {
+                log.trace("  No applicable security constraint defined");
             }
             return true;
         }
         for (SecurityConstraint constraint : constraints) {
             String userConstraint = constraint.getUserConstraint();
             if (userConstraint == null) {
-                if (log.isDebugEnabled()) {
-                    log.debug("  No applicable user data constraint defined");
+                if (log.isTraceEnabled()) {
+                    log.trace("  No applicable user data constraint defined");
                 }
                 return true;
             }
             if (userConstraint.equals(TransportGuarantee.NONE.name())) {
-                if (log.isDebugEnabled()) {
-                    log.debug("  User data constraint has no restrictions");
+                if (log.isTraceEnabled()) {
+                    log.trace("  User data constraint has no restrictions");
                 }
                 return true;
             }
@@ -995,8 +998,8 @@ public abstract class RealmBase extends LifecycleMBeanBase implements Realm {
         }
         // Validate the request against the user data constraint
         if (request.getRequest().isSecure()) {
-            if (log.isDebugEnabled()) {
-                log.debug("  User data constraint already satisfied");
+            if (log.isTraceEnabled()) {
+                log.trace("  User data constraint already satisfied");
             }
             return true;
         }
@@ -1005,8 +1008,8 @@ public abstract class RealmBase extends LifecycleMBeanBase implements Realm {
 
         // Is redirecting disabled?
         if (redirectPort <= 0) {
-            if (log.isDebugEnabled()) {
-                log.debug("  SSL redirect is disabled");
+            if (log.isTraceEnabled()) {
+                log.trace("  SSL redirect is disabled");
             }
             response.sendError(HttpServletResponse.SC_FORBIDDEN, request.getRequestURI());
             return false;
@@ -1036,8 +1039,8 @@ public abstract class RealmBase extends LifecycleMBeanBase implements Realm {
             file.append('?');
             file.append(queryString);
         }
-        if (log.isDebugEnabled()) {
-            log.debug("  Redirecting to " + file.toString());
+        if (log.isTraceEnabled()) {
+            log.trace("  Redirecting to " + file.toString());
         }
         response.sendRedirect(file.toString(), transportGuaranteeRedirectStatus);
         return false;
@@ -1204,8 +1207,8 @@ public abstract class RealmBase extends LifecycleMBeanBase implements Realm {
     protected Principal getPrincipal(X509Certificate usercert) {
         String username = x509UsernameRetriever.getUsername(usercert);
 
-        if (log.isDebugEnabled()) {
-            log.debug(sm.getString("realmBase.gotX509Username", username));
+        if (log.isTraceEnabled()) {
+            log.trace(sm.getString("realmBase.gotX509Username", username));
         }
 
         return getPrincipal(username);
@@ -1222,6 +1225,20 @@ public abstract class RealmBase extends LifecycleMBeanBase implements Realm {
     protected abstract Principal getPrincipal(String username);
 
 
+    /**
+     * Get the principal associated with the specified {@link GSSName}.
+     *
+     * @param gssName       The GSS name
+     * @param gssCredential the GSS credential of the principal
+     * @param gssContext    the established GSS context
+     *
+     * @return the principal associated with the given user name.
+     */
+    protected Principal getPrincipal(GSSName gssName, GSSCredential gssCredential, GSSContext gssContext) {
+        return getPrincipal(gssName, gssCredential);
+    }
+
+
     /**
      * Get the principal associated with the specified {@link GSSName}.
      *
@@ -1295,6 +1312,8 @@ public abstract class RealmBase extends LifecycleMBeanBase implements Realm {
      * specified, the default for the CredentialHandler will be used.</li>
      * <li><b>-h</b> - The fully qualified class name of the CredentialHandler to use. If not specified, the built-in
      * handlers will be tested in turn and the first one to accept the specified algorithm will be used.</li>
+     * <li><b>-f</b> - The name of the file that contains passwords to encode. Each line in the file should contain only
+     * one password. Using this option ignores other password input.</li>
      * </ul>
      * <p>
      * This generation process currently supports the following CredentialHandlers, the correct one being selected based
@@ -1306,8 +1325,10 @@ public abstract class RealmBase extends LifecycleMBeanBase implements Realm {
      * </ul>
      *
      * @param args The parameters passed on the command line
+     *
+     * @throws IOException If an error occurs reading the password file
      */
-    public static void main(String args[]) {
+    public static void main(String args[]) throws IOException {
 
         // Use negative values since null is not an option to indicate 'not set'
         int saltLength = -1;
@@ -1319,6 +1340,8 @@ public abstract class RealmBase extends LifecycleMBeanBase implements Realm {
         // the command line
         String algorithm = null;
         String handlerClassName = null;
+        // File name to read password(s) from
+        String passwordFile = null;
 
         if (args.length == 0) {
             usage();
@@ -1326,8 +1349,13 @@ public abstract class RealmBase extends LifecycleMBeanBase implements Realm {
         }
 
         int argIndex = 0;
+        // Boolean to check and see if we've reached the -- option
+        boolean endOfList = false;
 
-        while (args.length > argIndex + 2 && args[argIndex].length() == 2 && args[argIndex].charAt(0) == '-') {
+        // Note: Reducing args.length requirement to argIndex+1 so that -f works and ignores
+        // trailing words
+        while (args.length > argIndex + 1 && args[argIndex].length() == 2 && args[argIndex].charAt(0) == '-' &&
+                !endOfList) {
             switch (args[argIndex].charAt(1)) {
                 case 'a': {
                     algorithm = args[argIndex + 1];
@@ -1353,6 +1381,18 @@ public abstract class RealmBase extends LifecycleMBeanBase implements Realm {
                     handlerClassName = args[argIndex + 1];
                     break;
                 }
+                case 'f': {
+                    passwordFile = args[argIndex + 1];
+                    break;
+                }
+                case '-': {
+                    // When encountering -- option don't parse anything else as an option
+                    endOfList = true;
+                    // The -- opt doesn't take an argument, decrement the argIndex so that it parses
+                    // all remaining args
+                    argIndex--;
+                    break;
+                }
                 default: {
                     usage();
                     return;
@@ -1412,18 +1452,45 @@ public abstract class RealmBase extends LifecycleMBeanBase implements Realm {
         if (keyLength > 0) {
             IntrospectionUtils.setProperty(handler, "keyLength", Integer.toString(keyLength));
         }
+        if (passwordFile != null) {
+            // If the file name is used, then don't parse the trailing arguments
+            argIndex = args.length;
 
+            // Special case, allow for - filename to refer to stdin
+            try (BufferedReader br = passwordFile.equals("-") ? new BufferedReader(new InputStreamReader(System.in)) :
+                    new BufferedReader(new FileReader(passwordFile))) {
+                String line;
+                while ((line = br.readLine()) != null) {
+                    // Mutate each line in the file, or stdin
+                    mutateCredential(line, handler);
+                }
+            } catch (Exception e) {
+                // A FileNotFound is the likely exception here and self-explanatory. Softly
+                // reporting it and exit 1 so that you can tell it failed from the command line.
+                if (e instanceof java.io.FileNotFoundException) {
+                    System.err.println("cannot stat '" + passwordFile + "': No such file or directory");
+                    // Not sure if using an exit here is OK, but I wanted to return a code that
+                    // showed failure.
+                    System.exit(1);
+                } else {
+                    throw e;
+                }
+            }
+        }
         for (; argIndex < args.length; argIndex++) {
-            String credential = args[argIndex];
-            System.out.print(credential + ":");
-            System.out.println(handler.mutate(credential));
+            mutateCredential(args[argIndex], handler);
         }
     }
 
+    private static void mutateCredential(String credential, CredentialHandler handler) {
+        System.out.print(credential + ":");
+        System.out.println(handler.mutate(credential));
+    }
 
     private static void usage() {
-        System.out.println("Usage: RealmBase [-a <algorithm>] [-e <encoding>] " +
-                "[-i <iterations>] [-s <salt-length>] [-k <key-length>] " + "[-h <handler-class-name>] <credentials>");
+        System.out.println("Usage: RealmBase [-a <algorithm>] [-e <encoding>]" +
+                " [-i <iterations>] [-s <salt-length>] [-k <key-length>]" +
+                " [-h <handler-class-name>] | <XX credentials>");
     }
 
 
