@@ -14,7 +14,6 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.catalina.storeconfig;
 
 import java.io.PrintWriter;
@@ -32,26 +31,23 @@ public class CredentialHandlerSF extends StoreFactoryBase {
     private static Log log = LogFactory.getLog(CredentialHandlerSF.class);
 
     @Override
-    public void store(PrintWriter aWriter, int indent, Object aElement)
-            throws Exception {
+    public void store(PrintWriter aWriter, int indent, Object aElement) throws Exception {
         if (aElement instanceof NestedCredentialHandler) {
-            StoreDescription elementDesc = getRegistry().findDescription(
-                    aElement.getClass());
+            StoreDescription elementDesc = getRegistry().findDescription(aElement.getClass());
 
             if (elementDesc != null) {
-                if (log.isDebugEnabled())
-                    log.debug(sm.getString("factory.storeTag",
-                            elementDesc.getTag(), aElement));
+                if (log.isTraceEnabled()) {
+                    log.trace(sm.getString("factory.storeTag", elementDesc.getTag(), aElement));
+                }
                 getStoreAppender().printIndent(aWriter, indent + 2);
-                getStoreAppender().printOpenTag(aWriter, indent + 2, aElement,
-                            elementDesc);
+                getStoreAppender().printOpenTag(aWriter, indent + 2, aElement, elementDesc);
                 storeChildren(aWriter, indent + 2, aElement, elementDesc);
                 getStoreAppender().printIndent(aWriter, indent + 2);
                 getStoreAppender().printCloseTag(aWriter, elementDesc);
             } else {
-                if (log.isWarnEnabled())
-                    log.warn(sm.getString("factory.storeNoDescriptor",
-                            aElement.getClass()));
+                if (log.isWarnEnabled()) {
+                    log.warn(sm.getString("factory.storeNoDescriptor", aElement.getClass()));
+                }
             }
         } else {
             super.store(aWriter, indent, aElement);
@@ -60,20 +56,12 @@ public class CredentialHandlerSF extends StoreFactoryBase {
 
     /**
      * Store the specified CredentialHandler properties and child (CredentialHandler)
-     *
-     * @param aWriter
-     *            PrintWriter to which we are storing
-     * @param indent
-     *            Number of spaces to indent this element
-     * @param aCredentialHandler
-     *            CredentialHandler whose properties are being stored
-     *
-     * @exception Exception
-     *                if an exception occurs while storing
+     * <p>
+     * {@inheritDoc}
      */
     @Override
-    public void storeChildren(PrintWriter aWriter, int indent, Object aCredentialHandler,
-            StoreDescription parentDesc) throws Exception {
+    public void storeChildren(PrintWriter aWriter, int indent, Object aCredentialHandler, StoreDescription parentDesc)
+            throws Exception {
         if (aCredentialHandler instanceof NestedCredentialHandler) {
             NestedCredentialHandler nestedCredentialHandler = (NestedCredentialHandler) aCredentialHandler;
 
@@ -83,4 +71,4 @@ public class CredentialHandlerSF extends StoreFactoryBase {
         }
     }
 
-}
\ No newline at end of file
+}
