@@ -1,4 +1,4 @@
-/*
+/**
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -17,9 +17,6 @@
 package org.apache.catalina.storeconfig;
 
 import java.io.PrintWriter;
-import java.util.Arrays;
-import java.util.HashSet;
-import java.util.Set;
 
 import org.apache.tomcat.util.net.openssl.OpenSSLConf;
 import org.apache.tomcat.util.net.openssl.OpenSSLConfCmd;
@@ -29,8 +26,6 @@ import org.apache.tomcat.util.net.openssl.OpenSSLConfCmd;
  */
 public class OpenSSLConfSF extends StoreFactoryBase {
 
-    private static final Set<String> INTERNAL_COMMANDS = new HashSet<>(Arrays.asList(OpenSSLConfCmd.NO_OCSP_CHECK));
-
     /**
      * Store nested OpenSSLConfCmd elements.
      * <p>
@@ -42,13 +37,9 @@ public class OpenSSLConfSF extends StoreFactoryBase {
         if (aOpenSSLConf instanceof OpenSSLConf) {
             OpenSSLConf openSslConf = (OpenSSLConf) aOpenSSLConf;
             // Store nested <OpenSSLConfCmd> elements
-            for (OpenSSLConfCmd openSSLConfCmd : openSslConf.getCommands()) {
-                // Don't store the internal commands that are created from other SslHostConfig attributes.
-                if (INTERNAL_COMMANDS.contains(openSSLConfCmd.getName())) {
-                    continue;
-                }
-                storeElement(aWriter, indent + 2, openSSLConfCmd);
-            }
+            OpenSSLConfCmd[] openSSLConfCmds = openSslConf.getCommands().toArray(new OpenSSLConfCmd[0]);
+            storeElementArray(aWriter, indent + 2, openSSLConfCmds);
         }
     }
+
 }
