@@ -33,20 +33,16 @@ import org.apache.catalina.tribes.util.StringManager;
 import org.apache.juli.logging.Log;
 import org.apache.juli.logging.LogFactory;
 
-public class StaticMembershipInterceptor extends ChannelInterceptorBase
-        implements StaticMembershipInterceptorMBean {
+public class StaticMembershipInterceptor extends ChannelInterceptorBase implements StaticMembershipInterceptorMBean {
 
     private static final Log log = LogFactory.getLog(StaticMembershipInterceptor.class);
-    protected static final StringManager sm =
-            StringManager.getManager(StaticMembershipInterceptor.class);
+    protected static final StringManager sm = StringManager.getManager(StaticMembershipInterceptor.class);
 
-    protected static final byte[] MEMBER_START = new byte[] {
-        76, 111, 99, 97, 108, 32, 83, 116, 97, 116, 105, 99, 77, 101, 109, 98, 101, 114, 32, 78,
-        111, 116, 105, 102, 105, 99, 97, 116, 105, 111, 110, 32, 68, 97, 116, 97};
+    protected static final byte[] MEMBER_START = new byte[] { 76, 111, 99, 97, 108, 32, 83, 116, 97, 116, 105, 99, 77,
+            101, 109, 98, 101, 114, 32, 78, 111, 116, 105, 102, 105, 99, 97, 116, 105, 111, 110, 32, 68, 97, 116, 97 };
 
-    protected static final byte[] MEMBER_STOP = new byte[] {
-        76, 111, 99, 97, 108, 32, 83, 116, 97, 116, 105, 99, 77, 101, 109, 98, 101, 114, 32, 83,
-        104, 117, 116, 100, 111, 119, 110, 32, 68, 97, 116, 97};
+    protected static final byte[] MEMBER_STOP = new byte[] { 76, 111, 99, 97, 108, 32, 83, 116, 97, 116, 105, 99, 77,
+            101, 109, 98, 101, 114, 32, 83, 104, 117, 116, 100, 111, 119, 110, 32, 68, 97, 116, 97 };
 
     protected final ArrayList<Member> members = new ArrayList<>();
     protected Member localMember = null;
@@ -86,7 +82,7 @@ public class StaticMembershipInterceptor extends ChannelInterceptorBase
                 super.memberAdded(member);
             }
         } else if (msg.getMessage().getLength() == MEMBER_STOP.length &&
-                    Arrays.equals(MEMBER_STOP, msg.getMessage().getBytes())) {
+                Arrays.equals(MEMBER_STOP, msg.getMessage().getBytes())) {
             // receive member shutdown
             Member member = getMember(msg.getAddress());
             if (member != null) {
@@ -102,21 +98,14 @@ public class StaticMembershipInterceptor extends ChannelInterceptorBase
         }
     }
 
-    /**
-     * has members
-     */
     @Override
     public boolean hasMembers() {
-        return super.hasMembers() || (members.size()>0);
+        return super.hasMembers() || (members.size() > 0);
     }
 
-    /**
-     * Get all current cluster members
-     * @return all members or empty array
-     */
     @Override
     public Member[] getMembers() {
-        if ( members.size() == 0 ) {
+        if (members.size() == 0) {
             return super.getMembers();
         } else {
             synchronized (members) {
@@ -130,31 +119,22 @@ public class StaticMembershipInterceptor extends ChannelInterceptorBase
                 }
                 AbsoluteOrder.absoluteOrder(result);
                 return result;
-            }//sync
-        }//end if
+            } // sync
+        } // end if
     }
 
-    /**
-     * @param mbr Member
-     * @return Member
-     */
     @Override
     public Member getMember(Member mbr) {
-        if ( members.contains(mbr) ) {
+        if (members.contains(mbr)) {
             return members.get(members.indexOf(mbr));
         } else {
             return super.getMember(mbr);
         }
     }
 
-    /**
-     * Return the member that represents this node.
-     *
-     * @return Member
-     */
     @Override
     public Member getLocalMember(boolean incAlive) {
-        if (this.localMember != null ) {
+        if (this.localMember != null) {
             return localMember;
         } else {
             return super.getLocalMember(incAlive);
@@ -168,10 +148,10 @@ public class StaticMembershipInterceptor extends ChannelInterceptorBase
      */
     @Override
     public void start(int svc) throws ChannelException {
-        if ( (Channel.SND_RX_SEQ&svc)==Channel.SND_RX_SEQ ) {
+        if ((Channel.SND_RX_SEQ & svc) == Channel.SND_RX_SEQ) {
             super.start(Channel.SND_RX_SEQ);
         }
-        if ( (Channel.SND_TX_SEQ&svc)==Channel.SND_TX_SEQ ) {
+        if ((Channel.SND_TX_SEQ & svc) == Channel.SND_TX_SEQ) {
             super.start(Channel.SND_TX_SEQ);
         }
         final ChannelInterceptorBase base = this;
@@ -180,7 +160,7 @@ public class StaticMembershipInterceptor extends ChannelInterceptorBase
             Runnable r = () -> {
                 base.memberAdded(member);
                 if (getfirstInterceptor().getMember(member) != null) {
-                    sendLocalMember(new Member[]{member});
+                    sendLocalMember(new Member[] { member });
                 }
             };
             executor.execute(r);
@@ -192,7 +172,7 @@ public class StaticMembershipInterceptor extends ChannelInterceptorBase
         TcpPingInterceptor pingInterceptor = null;
         ChannelInterceptor prev = getPrevious();
         while (prev != null) {
-            if (prev instanceof TcpFailureDetector ) {
+            if (prev instanceof TcpFailureDetector) {
                 failureDetector = (TcpFailureDetector) prev;
             }
             if (prev instanceof TcpPingInterceptor) {
@@ -225,7 +205,7 @@ public class StaticMembershipInterceptor extends ChannelInterceptorBase
         try {
             sendMemberMessage(members, MEMBER_START);
         } catch (ChannelException cx) {
-            log.warn(sm.getString("staticMembershipInterceptor.sendLocalMember.failed"),cx);
+            log.warn(sm.getString("staticMembershipInterceptor.sendLocalMember.failed"), cx);
         }
     }
 
@@ -233,7 +213,7 @@ public class StaticMembershipInterceptor extends ChannelInterceptorBase
         try {
             sendMemberMessage(members, MEMBER_STOP);
         } catch (ChannelException cx) {
-            log.warn(sm.getString("staticMembershipInterceptor.sendShutdown.failed"),cx);
+            log.warn(sm.getString("staticMembershipInterceptor.sendShutdown.failed"), cx);
         }
     }
 
@@ -248,7 +228,7 @@ public class StaticMembershipInterceptor extends ChannelInterceptorBase
     }
 
     protected void sendMemberMessage(Member[] members, byte[] message) throws ChannelException {
-        if ( members == null || members.length == 0 ) {
+        if (members == null || members.length == 0) {
             return;
         }
         ChannelData data = new ChannelData(true);
