@@ -38,8 +38,8 @@ import org.apache.juli.logging.LogFactory;
 import org.apache.tomcat.util.json.JSONParser;
 
 /**
- * A {@link org.apache.catalina.tribes.MembershipProvider} that uses Kubernetes API to retrieve the members of a cluster.<br>
- *
+ * A {@link org.apache.catalina.tribes.MembershipProvider} that uses Kubernetes API to retrieve the members of a
+ * cluster.<br>
  */
 
 public class KubernetesMembershipProvider extends CloudMembershipProvider {
@@ -57,14 +57,15 @@ public class KubernetesMembershipProvider extends CloudMembershipProvider {
         String namespace = getNamespace();
 
         if (log.isDebugEnabled()) {
-            log.debug(String.format("Namespace [%s] set; clustering enabled", namespace));
+            log.debug(sm.getString("cloudMembershipProvider.start", namespace));
         }
 
         String protocol = getEnv(CUSTOM_ENV_PREFIX + "MASTER_PROTOCOL", "KUBERNETES_MASTER_PROTOCOL");
         String masterHost = getEnv(CUSTOM_ENV_PREFIX + "MASTER_HOST", "KUBERNETES_SERVICE_HOST");
         String masterPort = getEnv(CUSTOM_ENV_PREFIX + "MASTER_PORT", "KUBERNETES_SERVICE_PORT");
 
-        String clientCertificateFile = getEnv(CUSTOM_ENV_PREFIX + "CLIENT_CERT_FILE", "KUBERNETES_CLIENT_CERTIFICATE_FILE");
+        String clientCertificateFile =
+                getEnv(CUSTOM_ENV_PREFIX + "CLIENT_CERT_FILE", "KUBERNETES_CLIENT_CERTIFICATE_FILE");
         String caCertFile = getEnv(CUSTOM_ENV_PREFIX + "CA_CERT_FILE", "KUBERNETES_CA_CERTIFICATE_FILE");
         if (caCertFile == null) {
             caCertFile = "/var/run/secrets/kubernetes.io/serviceaccount/ca.crt";
@@ -98,7 +99,8 @@ public class KubernetesMembershipProvider extends CloudMembershipProvider {
             if (clientKeyAlgo == null) {
                 clientKeyAlgo = "RSA";
             }
-            streamProvider = new CertificateStreamProvider(clientCertificateFile, clientKeyFile, clientKeyPassword, clientKeyAlgo, caCertFile);
+            streamProvider = new CertificateStreamProvider(clientCertificateFile, clientKeyFile, clientKeyPassword,
+                    clientKeyAlgo, caCertFile);
         }
 
         String ver = getEnv(CUSTOM_ENV_PREFIX + "API_VERSION", "KUBERNETES_API_VERSION");
@@ -151,7 +153,7 @@ public class KubernetesMembershipProvider extends CloudMembershipProvider {
     protected void parsePods(Reader reader, List<MemberImpl> members) {
         JSONParser parser = new JSONParser(reader);
         try {
-            LinkedHashMap<String, Object> json = parser.object();
+            LinkedHashMap<String,Object> json = parser.object();
             Object itemsObject = json.get("items");
             if (!(itemsObject instanceof List<?>)) {
                 log.error(sm.getString("kubernetesMembershipProvider.invalidPodsList", "no items"));
@@ -159,11 +161,11 @@ public class KubernetesMembershipProvider extends CloudMembershipProvider {
             }
             List<Object> items = (List<Object>) itemsObject;
             for (Object podObject : items) {
-                if (!(podObject instanceof LinkedHashMap<?, ?>)) {
+                if (!(podObject instanceof LinkedHashMap<?,?>)) {
                     log.warn(sm.getString("kubernetesMembershipProvider.invalidPod", "item"));
                     continue;
                 }
-                LinkedHashMap<String, Object> pod = (LinkedHashMap<String, Object>) podObject;
+                LinkedHashMap<String,Object> pod = (LinkedHashMap<String,Object>) podObject;
                 // If there is a "kind", check it is "Pod"
                 Object podKindObject = pod.get("kind");
                 if (podKindObject != null && !"Pod".equals(podKindObject)) {
@@ -171,11 +173,11 @@ public class KubernetesMembershipProvider extends CloudMembershipProvider {
                 }
                 // "metadata" contains "name", "uid" and "creationTimestamp"
                 Object metadataObject = pod.get("metadata");
-                if (!(metadataObject instanceof LinkedHashMap<?, ?>)) {
+                if (!(metadataObject instanceof LinkedHashMap<?,?>)) {
                     log.warn(sm.getString("kubernetesMembershipProvider.invalidPod", "metadata"));
                     continue;
                 }
-                LinkedHashMap<String, Object> metadata = (LinkedHashMap<String, Object>) metadataObject;
+                LinkedHashMap<String,Object> metadata = (LinkedHashMap<String,Object>) metadataObject;
                 Object nameObject = metadata.get("name");
                 if (nameObject == null) {
                     log.warn(sm.getString("kubernetesMembershipProvider.invalidPod", "name"));
@@ -189,11 +191,11 @@ public class KubernetesMembershipProvider extends CloudMembershipProvider {
                 }
                 // "status" contains "phase" (which must be "Running") and "podIP"
                 Object statusObject = pod.get("status");
-                if (!(statusObject instanceof LinkedHashMap<?, ?>)) {
+                if (!(statusObject instanceof LinkedHashMap<?,?>)) {
                     log.warn(sm.getString("kubernetesMembershipProvider.invalidPod", "status"));
                     continue;
                 }
-                LinkedHashMap<String, Object> status = (LinkedHashMap<String, Object>) statusObject;
+                LinkedHashMap<String,Object> status = (LinkedHashMap<String,Object>) statusObject;
                 if (!"Running".equals(status.get("phase"))) {
                     continue;
                 }
@@ -209,14 +211,16 @@ public class KubernetesMembershipProvider extends CloudMembershipProvider {
                 if (podIP.equals(localIp)) {
                     // Update the UID on initial lookup
                     Member localMember = service.getLocalMember(false);
-                    if (localMember.getUniqueId() == CloudMembershipService.INITIAL_ID && localMember instanceof MemberImpl) {
+                    if (localMember.getUniqueId() == CloudMembershipService.INITIAL_ID &&
+                            localMember instanceof MemberImpl) {
                         byte[] id = md5.digest(uid.getBytes(StandardCharsets.US_ASCII));
                         ((MemberImpl) localMember).setUniqueId(id);
                     }
                     continue;
                 }
 
-                long aliveTime = Duration.between(Instant.parse(creationTimestampObject.toString()), startTime).toMillis();
+                long aliveTime =
+                        Duration.between(Instant.parse(creationTimestampObject.toString()), startTime).toMillis();
 
                 MemberImpl member = null;
                 try {
