@@ -32,7 +32,11 @@ public class QuotedStringTokenizer {
     private int returnedTokens = 0;
 
     enum WordMode {
-        SPACES, QUOTED, ESCAPED, SIMPLE, COMMENT
+        SPACES,
+        QUOTED,
+        ESCAPED,
+        SIMPLE,
+        COMMENT
     }
 
     public QuotedStringTokenizer(String text) {
@@ -55,27 +59,27 @@ public class QuotedStringTokenizer {
         while (pos < length) {
             char currentChar = inputText.charAt(pos);
             switch (currentMode) {
-            case SPACES:
-                currentMode = handleSpaces(currentToken, currentChar);
-                break;
-            case QUOTED:
-                currentMode = handleQuoted(tokens, currentToken, currentChar);
-                break;
-            case ESCAPED:
-                currentToken.append(currentChar);
-                currentMode = WordMode.QUOTED;
-                break;
-            case SIMPLE:
-                currentMode = handleSimple(tokens, currentToken, currentChar);
-                break;
-            case COMMENT:
-                if (currentChar == '\r' || currentChar == '\n') {
-                    currentMode = WordMode.SPACES;
-                }
-                break;
-            default:
-                throw new IllegalStateException(sm.getString("quotedStringTokenizer.tokenizeError",
-                                inputText, Integer.valueOf(pos), currentMode));
+                case SPACES:
+                    currentMode = handleSpaces(currentToken, currentChar);
+                    break;
+                case QUOTED:
+                    currentMode = handleQuoted(tokens, currentToken, currentChar);
+                    break;
+                case ESCAPED:
+                    currentToken.append(currentChar);
+                    currentMode = WordMode.QUOTED;
+                    break;
+                case SIMPLE:
+                    currentMode = handleSimple(tokens, currentToken, currentChar);
+                    break;
+                case COMMENT:
+                    if (currentChar == '\r' || currentChar == '\n') {
+                        currentMode = WordMode.SPACES;
+                    }
+                    break;
+                default:
+                    throw new IllegalStateException(sm.getString("quotedStringTokenizer.tokenizeError", inputText,
+                            Integer.valueOf(pos), currentMode));
             }
             pos++;
         }
