@@ -22,9 +22,12 @@ import java.util.Map;
 import java.util.regex.Matcher;
 
 import org.apache.catalina.util.URLEncoder;
+import org.apache.tomcat.util.res.StringManager;
 
 public class Substitution {
 
+    protected static final StringManager sm = StringManager.getManager(Substitution.class);
+
     public abstract static class SubstitutionElement {
         public abstract String evaluate(Matcher rule, Matcher cond, Resolver resolver);
     }
@@ -41,6 +44,7 @@ public class Substitution {
 
     public class RewriteRuleBackReferenceElement extends SubstitutionElement {
         public int n;
+
         @Override
         public String evaluate(Matcher rule, Matcher cond, Resolver resolver) {
             String result = rule.group(n);
@@ -49,9 +53,9 @@ public class Substitution {
             }
             if (escapeBackReferences) {
                 // Note: This should be consistent with the way httpd behaves.
-                //       We might want to consider providing a dedicated decoder
-                //       with an option to add additional safe characters to
-                //       provide users with more flexibility
+                // We might want to consider providing a dedicated decoder
+                // with an option to add additional safe characters to
+                // provide users with more flexibility
                 return URLEncoder.DEFAULT.encode(result, resolver.getUriCharset());
             } else {
                 return result;
@@ -61,6 +65,7 @@ public class Substitution {
 
     public static class RewriteCondBackReferenceElement extends SubstitutionElement {
         public int n;
+
         @Override
         public String evaluate(Matcher rule, Matcher cond, Resolver resolver) {
             return (cond.group(n) == null ? "" : cond.group(n));
@@ -69,6 +74,7 @@ public class Substitution {
 
     public static class ServerVariableElement extends SubstitutionElement {
         public String key;
+
         @Override
         public String evaluate(Matcher rule, Matcher cond, Resolver resolver) {
             return resolver.resolve(key);
@@ -77,6 +83,7 @@ public class Substitution {
 
     public static class ServerVariableEnvElement extends SubstitutionElement {
         public String key;
+
         @Override
         public String evaluate(Matcher rule, Matcher cond, Resolver resolver) {
             return resolver.resolveEnv(key);
@@ -85,6 +92,7 @@ public class Substitution {
 
     public static class ServerVariableSslElement extends SubstitutionElement {
         public String key;
+
         @Override
         public String evaluate(Matcher rule, Matcher cond, Resolver resolver) {
             return resolver.resolveSsl(key);
@@ -93,6 +101,7 @@ public class Substitution {
 
     public static class ServerVariableHttpElement extends SubstitutionElement {
         public String key;
+
         @Override
         public String evaluate(Matcher rule, Matcher cond, Resolver resolver) {
             return resolver.resolveHttp(key);
@@ -103,6 +112,7 @@ public class Substitution {
         public RewriteMap map = null;
         public SubstitutionElement[] defaultValue = null;
         public SubstitutionElement[] key = null;
+
         @Override
         public String evaluate(Matcher rule, Matcher cond, Resolver resolver) {
             String result = map.lookup(evaluateSubstitution(key, rule, cond, resolver));
@@ -116,19 +126,26 @@ public class Substitution {
     protected SubstitutionElement[] elements = null;
 
     protected String sub = null;
-    public String getSub() { return sub; }
-    public void setSub(String sub) { this.sub = sub; }
+
+    public String getSub() {
+        return sub;
+    }
+
+    public void setSub(String sub) {
+        this.sub = sub;
+    }
 
     private boolean escapeBackReferences;
+
     void setEscapeBackReferences(boolean escapeBackReferences) {
         this.escapeBackReferences = escapeBackReferences;
     }
 
-    public void parse(Map<String, RewriteMap> maps) {
+    public void parse(Map<String,RewriteMap> maps) {
         this.elements = parseSubstitution(sub, maps);
     }
 
-    private SubstitutionElement[] parseSubstitution(String sub, Map<String, RewriteMap> maps) {
+    private SubstitutionElement[] parseSubstitution(String sub, Map<String,RewriteMap> maps) {
 
         List<SubstitutionElement> elements = new ArrayList<>();
         int pos = 0;
@@ -148,7 +165,7 @@ public class Substitution {
                 elements.add(newElement);
             } else if (isFirstPos(backslashPos, dollarPos, percentPos)) {
                 if (backslashPos + 1 == sub.length()) {
-                    throw new IllegalArgumentException(sub);
+                    throw new IllegalArgumentException(sm.getString("substitution.invalid", sub));
                 }
                 StaticElement newElement = new StaticElement();
                 newElement.value = sub.substring(pos, backslashPos) + sub.substring(backslashPos + 1, backslashPos + 2);
@@ -157,7 +174,7 @@ public class Substitution {
             } else if (isFirstPos(dollarPos, percentPos)) {
                 // $: back reference to rule or map lookup
                 if (dollarPos + 1 == sub.length()) {
-                    throw new IllegalArgumentException(sub);
+                    throw new IllegalArgumentException(sm.getString("substitution.invalid", sub));
                 }
                 if (pos < dollarPos) {
                     // Static text
@@ -179,17 +196,18 @@ public class Substitution {
                     int def = findMatchingColonOrBar(false, sub, open);
                     int close = findMatchingBrace(sub, open);
                     if (!(-1 < open && open < colon && colon < close)) {
-                        throw new IllegalArgumentException(sub);
+                        throw new IllegalArgumentException(sm.getString("substitution.invalid", sub));
                     }
                     newElement.map = maps.get(sub.substring(open + 1, colon));
                     if (newElement.map == null) {
-                        throw new IllegalArgumentException(sub + ": No map: " + sub.substring(open + 1, colon));
+                        throw new IllegalArgumentException(
+                                sm.getString("substitution.noMap", sub.substring(open + 1, colon), sub));
                     }
                     String key = null;
                     String defaultValue = null;
                     if (def > -1) {
                         if (!(colon < def && def < close)) {
-                            throw new IllegalArgumentException(sub);
+                            throw new IllegalArgumentException(sm.getString("substitution.invalid", sub));
                         }
                         key = sub.substring(colon + 1, def);
                         defaultValue = sub.substring(def + 1, close);
@@ -203,12 +221,12 @@ public class Substitution {
                     pos = close + 1;
                     elements.add(newElement);
                 } else {
-                    throw new IllegalArgumentException(sub + ": missing digit or curly brace.");
+                    throw new IllegalArgumentException(sm.getString("substitution.missingDigit", sub));
                 }
             } else {
                 // %: back reference to condition or server variable
                 if (percentPos + 1 == sub.length()) {
-                    throw new IllegalArgumentException(sub);
+                    throw new IllegalArgumentException(sm.getString("substitution.invalid", sub));
                 }
                 if (pos < percentPos) {
                     // Static text
@@ -229,7 +247,7 @@ public class Substitution {
                     int colon = findMatchingColonOrBar(true, sub, open);
                     int close = findMatchingBrace(sub, open);
                     if (!(-1 < open && open < close)) {
-                        throw new IllegalArgumentException(sub);
+                        throw new IllegalArgumentException(sm.getString("substitution.invalid", sub));
                     }
                     if (colon > -1 && open < colon && colon < close) {
                         String type = sub.substring(open + 1, colon);
@@ -243,7 +261,7 @@ public class Substitution {
                             newElement = new ServerVariableHttpElement();
                             ((ServerVariableHttpElement) newElement).key = sub.substring(colon + 1, close);
                         } else {
-                            throw new IllegalArgumentException(sub + ": Bad type: " + type);
+                            throw new IllegalArgumentException(sm.getString("substitution.badType", type, sub));
                         }
                     } else {
                         newElement = new ServerVariableElement();
@@ -252,7 +270,7 @@ public class Substitution {
                     pos = close + 1;
                     elements.add(newElement);
                 } else {
-                    throw new IllegalArgumentException(sub + ": missing digit or curly brace.");
+                    throw new IllegalArgumentException(sm.getString("substitution.missingDigit", sub));
                 }
             }
         }
@@ -266,7 +284,7 @@ public class Substitution {
         for (int i = start + 1; i < sub.length(); i++) {
             char c = sub.charAt(i);
             if (c == '{') {
-                char previousChar = sub.charAt(i-1);
+                char previousChar = sub.charAt(i - 1);
                 if (previousChar == '$' || previousChar == '%') {
                     nesting++;
                 }
@@ -285,13 +303,13 @@ public class Substitution {
         for (int i = start + 1; i < sub.length(); i++) {
             char c = sub.charAt(i);
             if (c == '{') {
-                char previousChar = sub.charAt(i-1);
+                char previousChar = sub.charAt(i - 1);
                 if (previousChar == '$' || previousChar == '%') {
                     nesting++;
                 }
             } else if (c == '}') {
                 nesting--;
-            } else if (colon ? c == ':' : c =='|') {
+            } else if (colon ? c == ':' : c == '|') {
                 if (nesting == 0) {
                     return i;
                 }
@@ -302,9 +320,11 @@ public class Substitution {
 
     /**
      * Evaluate the substitution based on the context.
-     * @param rule corresponding matched rule
-     * @param cond last matched condition
+     *
+     * @param rule     corresponding matched rule
+     * @param cond     last matched condition
      * @param resolver The property resolver
+     *
      * @return The substitution result
      */
     public String evaluate(Matcher rule, Matcher cond, Resolver resolver) {
@@ -320,16 +340,14 @@ public class Substitution {
     }
 
     /**
-     * Checks whether the first int is non negative and smaller than any non negative other int
-     * given with {@code others}.
+     * Checks whether the first int is non negative and smaller than any non negative other int given with
+     * {@code others}.
      *
-     * @param testPos
-     *            integer to test against
-     * @param others
-     *            list of integers that are paired against {@code testPos}. Any
-     *            negative integer will be ignored.
-     * @return {@code true} if {@code testPos} is not negative and is less then any given other
-     *         integer, {@code false} otherwise
+     * @param testPos integer to test against
+     * @param others  list of integers that are paired against {@code testPos}. Any negative integer will be ignored.
+     *
+     * @return {@code true} if {@code testPos} is not negative and is less then any given other integer, {@code false}
+     *             otherwise
      */
     private boolean isFirstPos(int testPos, int... others) {
         if (testPos < 0) {
