@@ -25,8 +25,7 @@ import org.apache.catalina.WebResourceSet;
 import org.apache.catalina.util.LifecycleBase;
 import org.apache.tomcat.util.res.StringManager;
 
-public abstract class AbstractResourceSet extends LifecycleBase
-        implements WebResourceSet {
+public abstract class AbstractResourceSet extends LifecycleBase implements WebResourceSet {
 
     private WebResourceRoot root;
     private String base;
@@ -42,8 +41,7 @@ public abstract class AbstractResourceSet extends LifecycleBase
 
     protected final void checkPath(String path) {
         if (path == null || path.length() == 0 || path.charAt(0) != '/') {
-            throw new IllegalArgumentException(
-                    sm.getString("abstractResourceSet.checkPath", path));
+            throw new IllegalArgumentException(sm.getString("abstractResourceSet.checkPath", path));
         }
     }
 
@@ -122,7 +120,7 @@ public abstract class AbstractResourceSet extends LifecycleBase
     }
 
 
-    //-------------------------------------------------------- Lifecycle methods
+    // -------------------------------------------------------- Lifecycle methods
     @Override
     protected final void startInternal() throws LifecycleException {
         setState(LifecycleState.STARTING);
