@@ -39,7 +39,9 @@ import org.apache.catalina.WebResource;
 import org.apache.catalina.WebResourceRoot;
 import org.apache.juli.logging.Log;
 import org.apache.juli.logging.LogFactory;
+import org.apache.tomcat.util.buf.HexUtils;
 import org.apache.tomcat.util.res.StringManager;
+import org.apache.tomcat.util.security.ConcurrentMessageDigest;
 
 /**
  * This class is designed to wrap a 'raw' WebResource and providing caching for expensive operations. Inexpensive
@@ -73,6 +75,8 @@ public class CachedResource implements WebResource {
     private volatile Boolean cachedExists = null;
     private volatile Boolean cachedIsVirtual = null;
     private volatile Long cachedContentLength = null;
+    private final Object cachedContentLengthLock = new Object();
+    private volatile String cachedStrongETag = null;
 
 
     public CachedResource(Cache cache, StandardRoot root, String path, long ttl, int objectMaxSizeBytes,
@@ -243,13 +247,29 @@ public class CachedResource implements WebResource {
 
     @Override
     public long getContentLength() {
+        /*
+         * Cache the content length for two reasons.
+         *
+         * 1. It is relatively expensive to calculate, it shouldn't change and this method is called multiple times
+         * during cache validation. Caching, therefore, offers a performance benefit.
+         *
+         * 2. There is a race condition if concurrent threads are trying to PUT and DELETE the same resource. If the
+         * DELETE thread removes the cache entry after the PUT thread has created it but before validation is complete
+         * the DELETE thread sees a content length for a non-existant resource but the PUT thread sees the actual
+         * content length. While that isn't an issue for the individual requests it, does corrupt the cache size
+         * tracking as the size used for the resource is different between when it is added to the cache and when it is
+         * removed. Caching combined with locking ensures that a consistent content length is reported for the resource.
+         */
         if (cachedContentLength == null) {
-            long result = 0;
-            if (webResource != null) {
-                result = webResource.getContentLength();
-                cachedContentLength = Long.valueOf(result);
+            synchronized (cachedContentLengthLock) {
+                if (cachedContentLength == null) {
+                    if (webResource == null) {
+                        cachedContentLength = Long.valueOf(0);
+                    } else {
+                        cachedContentLength = Long.valueOf(webResource.getContentLength());
+                    }
+                }
             }
-            return result;
         }
         return cachedContentLength.longValue();
     }
@@ -274,6 +294,20 @@ public class CachedResource implements WebResource {
         return webResource.getETag();
     }
 
+    @Override
+    public String getStrongETag() {
+        if (cachedStrongETag == null) {
+            byte[] buf = getContent();
+            if (buf != null) {
+                buf = ConcurrentMessageDigest.digest("SHA-1", buf);
+                cachedStrongETag = "\"" + HexUtils.toHexString(buf) + "\"";
+            } else {
+                cachedStrongETag = webResource.getStrongETag();
+            }
+        }
+        return cachedStrongETag;
+    }
+
     @Override
     public void setMimeType(String mimeType) {
         webResource.setMimeType(mimeType);
@@ -326,7 +360,7 @@ public class CachedResource implements WebResource {
          *
          * One option to resolve this issue is to use a custom URL scheme for resource URLs. This would allow us, via
          * registration of a URLStreamHandlerFactory, to control how the resources are accessed and ensure that all
-         * access go via the cache We took this approach for war: URLs so we can use jar:war:file: URLs to reference
+         * access go via the cache. We took this approach for war: URLs so we can use jar:war:file: URLs to reference
          * resources in unpacked WAR files. However, because URL.setURLStreamHandlerFactory() may only be called once,
          * this can cause problems when using other libraries that also want to use a custom URL scheme.
          *
@@ -339,8 +373,8 @@ public class CachedResource implements WebResource {
             return null;
         }
         try {
-            CachedResourceURLStreamHandler handler = new CachedResourceURLStreamHandler(resourceURL, root, webAppPath,
-                    usesClassLoaderResources);
+            CachedResourceURLStreamHandler handler =
+                    new CachedResourceURLStreamHandler(resourceURL, root, webAppPath, usesClassLoaderResources);
             URL result = new URL(null, resourceURL.toExternalForm(), handler);
             handler.setCacheURL(result);
             return result;
