@@ -22,7 +22,7 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
 
-import javax.servlet.ServletContext;
+import jakarta.servlet.ServletContext;
 
 import org.apache.catalina.LifecycleException;
 import org.apache.catalina.WebResource;
@@ -79,7 +79,8 @@ public class ExtractingRoot extends StandardRoot {
 
     private File getExpansionTarget() {
         File tmpDir = (File) getContext().getServletContext().getAttribute(ServletContext.TEMPDIR);
-        return new File(tmpDir, APPLICATION_JARS_DIR);
+        File expansionTarget = new File(tmpDir, APPLICATION_JARS_DIR);
+        return expansionTarget;
     }
 
 
