@@ -289,6 +289,7 @@ class AsyncStateMachine {
             updateState(AsyncState.DISPATCHING);
             return SocketState.ASYNC_END;
         } else if (state == AsyncState.DISPATCHING) {
+            asyncCtxt.fireOnComplete();
             updateState(AsyncState.DISPATCHED);
             asyncCtxt.decrementInProgressAsyncCount();
             return SocketState.ASYNC_END;
@@ -420,8 +421,8 @@ class AsyncStateMachine {
         Request request = processor.getRequest();
         boolean containerThread = (request != null && request.isRequestThread());
 
-        if (log.isDebugEnabled()) {
-            log.debug(sm.getString("asyncStateMachine.asyncError.start"));
+        if (log.isTraceEnabled()) {
+            log.trace(sm.getString("asyncStateMachine.asyncError.start"));
         }
 
         clearNonBlockingListeners();
@@ -429,8 +430,8 @@ class AsyncStateMachine {
             updateState(AsyncState.MUST_ERROR);
         } else {
             if (hasProcessedError) {
-                if (log.isDebugEnabled()) {
-                    log.debug(sm.getString("asyncStateMachine.asyncError.skip"));
+                if (log.isTraceEnabled()) {
+                    log.trace(sm.getString("asyncStateMachine.asyncError.skip"));
                 }
                 return false;
             }
@@ -520,8 +521,8 @@ class AsyncStateMachine {
 
 
     private synchronized void updateState(AsyncState newState) {
-        if (log.isDebugEnabled()) {
-            log.debug(sm.getString("asyncStateMachine.stateChange", state, newState));
+        if (log.isTraceEnabled()) {
+            log.trace(sm.getString("asyncStateMachine.stateChange", state, newState));
         }
         state = newState;
     }
