@@ -89,7 +89,7 @@ public class AjpProcessor extends AbstractProcessor {
     private static final byte[] pongMessageArray;
 
 
-    private static final Map<String, String> jakartaAttributeMapping;
+    private static final Map<String,String> jakartaAttributeMapping;
     private static final Set<String> iisTlsAttributes;
 
 
@@ -131,7 +131,7 @@ public class AjpProcessor extends AbstractProcessor {
         System.arraycopy(pongMessage.getBuffer(), 0, pongMessageArray, 0, pongMessage.getLen());
 
         // Build Map of Java Servlet to Jakarta Servlet attribute names
-        Map<String, String> m = new HashMap<>();
+        Map<String,String> m = new HashMap<>();
         m.put("jakarta.servlet.request.cipher_suite", "jakarta.servlet.request.cipher_suite");
         m.put("jakarta.servlet.request.key_size", "jakarta.servlet.request.key_size");
         m.put("jakarta.servlet.request.ssl_session", "jakarta.servlet.request.ssl_session");
@@ -991,8 +991,8 @@ public class AjpProcessor extends AbstractProcessor {
                     responseMessage.appendBytes(hV);
                 } catch (IllegalArgumentException iae) {
                     // Log the problematic header
-                    log.warn(sm.getString("ajpprocessor.response.invalidHeader", headers.getName(i), headers.getValue(i)),
-                            iae);
+                    log.warn(sm.getString("ajpprocessor.response.invalidHeader", headers.getName(i),
+                            headers.getValue(i)), iae);
                     // Remove the problematic header
                     headers.removeHeader(i);
                     numHeaders--;
@@ -1054,6 +1054,12 @@ public class AjpProcessor extends AbstractProcessor {
     }
 
 
+    @Override
+    protected void earlyHints() throws IOException {
+        // NO-OP for AJP
+    }
+
+
     @Override
     protected final int available(boolean doRead) {
         if (endOfStream) {
