@@ -23,7 +23,7 @@ import java.util.concurrent.atomic.LongAdder;
 import org.apache.tomcat.util.modeler.BaseModelMBean;
 
 /**
- *  This aggregates the data collected from each UpgradeInfo instance.
+ * This aggregates the data collected from each UpgradeInfo instance.
  */
 public class UpgradeGroupInfo extends BaseModelMBean {
 
@@ -59,9 +59,12 @@ public class UpgradeGroupInfo extends BaseModelMBean {
         }
         return bytes;
     }
+
     public void setBytesReceived(long bytesReceived) {
         deadBytesReceived.reset();
-        deadBytesReceived.add(bytesReceived);
+        if (bytesReceived != 0) {
+            deadBytesReceived.add(bytesReceived);
+        }
         for (UpgradeInfo ui : upgradeInfos) {
             ui.setBytesReceived(bytesReceived);
         }
@@ -75,9 +78,12 @@ public class UpgradeGroupInfo extends BaseModelMBean {
         }
         return bytes;
     }
+
     public void setBytesSent(long bytesSent) {
         deadBytesSent.reset();
-        deadBytesSent.add(bytesSent);
+        if (bytesSent != 0) {
+            deadBytesSent.add(bytesSent);
+        }
         for (UpgradeInfo ui : upgradeInfos) {
             ui.setBytesSent(bytesSent);
         }
@@ -91,9 +97,12 @@ public class UpgradeGroupInfo extends BaseModelMBean {
         }
         return msgs;
     }
+
     public void setMsgsReceived(long msgsReceived) {
         deadMsgsReceived.reset();
-        deadMsgsReceived.add(msgsReceived);
+        if (msgsReceived != 0) {
+            deadMsgsReceived.add(msgsReceived);
+        }
         for (UpgradeInfo ui : upgradeInfos) {
             ui.setMsgsReceived(msgsReceived);
         }
@@ -107,9 +116,12 @@ public class UpgradeGroupInfo extends BaseModelMBean {
         }
         return msgs;
     }
+
     public void setMsgsSent(long msgsSent) {
         deadMsgsSent.reset();
-        deadMsgsSent.add(msgsSent);
+        if (msgsSent != 0) {
+            deadMsgsSent.add(msgsSent);
+        }
         for (UpgradeInfo ui : upgradeInfos) {
             ui.setMsgsSent(msgsSent);
         }
