@@ -157,7 +157,7 @@ public class Http2AsyncUpgradeHandler extends Http2UpgradeHandler {
                 boolean active = state.isActive();
                 state.sendReset();
                 if (active) {
-                    decrementActiveRemoteStreamCount();
+                    decrementActiveRemoteStreamCount(getStream(se.getStreamId()));
                 }
             }
 
