@@ -48,8 +48,7 @@ public class Stream {
             protected void findNext() {
                 while (iterator.hasNext()) {
                     Object obj = iterator.next();
-                    if (ELSupport.coerceToBoolean(null, le.invoke(obj),
-                            true).booleanValue()) {
+                    if (ELSupport.coerceToBoolean(null, le.invoke(obj), true).booleanValue()) {
                         next = obj;
                         foundNext = true;
                         break;
@@ -83,8 +82,7 @@ public class Stream {
 
             @Override
             protected void findNext() {
-                while (iterator.hasNext() ||
-                        (inner != null && inner.hasNext())) {
+                while (iterator.hasNext() || (inner != null && inner.hasNext())) {
                     if (inner == null || !inner.hasNext()) {
                         inner = ((Stream) le.invoke(iterator.next())).iterator;
                     }
@@ -343,7 +341,7 @@ public class Stream {
 
         while (iterator.hasNext()) {
             iterator.next();
-            count ++;
+            count++;
         }
 
         return Long.valueOf(count);
@@ -413,8 +411,7 @@ public class Stream {
             if ((obj instanceof Comparable)) {
                 result = (Comparable) obj;
             } else {
-                throw new ELException(
-                        MessageFactory.get("stream.compare.notComparable"));
+                throw new ELException(MessageFactory.get("stream.compare.notComparable"));
             }
         }
 
@@ -427,8 +424,7 @@ public class Stream {
                     result = (Comparable) obj;
                 }
             } else {
-                throw new ELException(
-                        MessageFactory.get("stream.compare.notComparable"));
+                throw new ELException(MessageFactory.get("stream.compare.notComparable"));
             }
         }
 
@@ -450,11 +446,9 @@ public class Stream {
 
         while (iterator.hasNext()) {
             Object obj = iterator.next();
-            if (isMax && ELSupport.coerceToNumber(null, le.invoke(obj, result),
-                    Integer.class).intValue() > 0) {
+            if (isMax && ELSupport.coerceToNumber(null, le.invoke(obj, result), Integer.class).intValue() > 0) {
                 result = obj;
-            } else if (!isMax && ELSupport.coerceToNumber(null, le.invoke(obj, result),
-                    Integer.class).intValue() < 0) {
+            } else if (!isMax && ELSupport.coerceToNumber(null, le.invoke(obj, result), Integer.class).intValue() < 0) {
                 result = obj;
             }
         }
@@ -467,8 +461,7 @@ public class Stream {
     }
 
 
-    private static class LambdaExpressionComparator
-            implements Comparator<Object> {
+    private static class LambdaExpressionComparator implements Comparator<Object> {
 
         private final LambdaExpression le;
 
@@ -478,8 +471,7 @@ public class Stream {
 
         @Override
         public int compare(Object o1, Object o2) {
-            return ELSupport.coerceToNumber(
-                    null, le.invoke(o1, o2), Integer.class).intValue();
+            return ELSupport.coerceToNumber(null, le.invoke(o1, o2), Integer.class).intValue();
         }
     }
 
