@@ -54,11 +54,8 @@ import org.eclipse.jdt.internal.compiler.impl.CompilerOptions;
 import org.eclipse.jdt.internal.compiler.problem.DefaultProblemFactory;
 
 /**
- * JDT class compiler. This compiler will load source dependencies from the
- * context classloader, reducing dramatically disk access during
- * the compilation process.
- *
- * Based on code from Cocoon2.
+ * JDT class compiler. This compiler will load source dependencies from the context classloader, reducing dramatically
+ * disk access during the compilation process. Based on code from Cocoon2.
  *
  * @author Remy Maucherat
  */
@@ -68,7 +65,7 @@ public class JDTCompiler extends org.apache.jasper.compiler.Compiler {
 
     @Override
     protected void generateClass(Map<String,SmapStratum> smaps)
-        throws FileNotFoundException, JasperException, Exception {
+            throws FileNotFoundException, JasperException, Exception {
 
         long t1 = 0;
         if (log.isDebugEnabled()) {
@@ -81,8 +78,8 @@ public class JDTCompiler extends org.apache.jasper.compiler.Compiler {
         final String targetClassName =
                 ((packageName.length() != 0) ? (packageName + ".") : "") + ctxt.getServletClassName();
         final ClassLoader classLoader = ctxt.getJspLoader();
-        String[] fileNames = new String[] {sourceFile};
-        String[] classNames = new String[] {targetClassName};
+        String[] fileNames = new String[] { sourceFile };
+        String[] classNames = new String[] { targetClassName };
         final List<JavacErrorDetail> problemList = new ArrayList<>();
 
         class CompilationUnit implements ICompilationUnit {
@@ -132,7 +129,7 @@ public class JDTCompiler extends org.apache.jasper.compiler.Compiler {
             @Override
             public char[][] getPackageName() {
                 StringTokenizer izer = new StringTokenizer(className, ".");
-                char[][] result = new char[izer.countTokens()-1][];
+                char[][] result = new char[izer.countTokens() - 1][];
                 for (int i = 0; i < result.length; i++) {
                     String tok = izer.nextToken();
                     result[i] = tok.toCharArray();
@@ -148,169 +145,163 @@ public class JDTCompiler extends org.apache.jasper.compiler.Compiler {
 
         final INameEnvironment env = new INameEnvironment() {
 
-                @Override
-                public NameEnvironmentAnswer findType(char[][] compoundTypeName) {
-                    StringBuilder result = new StringBuilder();
-                    for (int i = 0; i < compoundTypeName.length; i++) {
-                        if (i > 0) {
-                            result.append('.');
-                        }
-                        result.append(compoundTypeName[i]);
-                    }
-                    return findType(result.toString());
-                }
-
-                @Override
-                public NameEnvironmentAnswer findType(char[] typeName, char[][] packageName) {
-                    StringBuilder result = new StringBuilder();
-                    int i=0;
-                    for (; i < packageName.length; i++) {
-                        if (i > 0) {
-                            result.append('.');
-                        }
-                        result.append(packageName[i]);
-                    }
+            @Override
+            public NameEnvironmentAnswer findType(char[][] compoundTypeName) {
+                StringBuilder result = new StringBuilder();
+                for (int i = 0; i < compoundTypeName.length; i++) {
                     if (i > 0) {
                         result.append('.');
                     }
-                    result.append(typeName);
-                    return findType(result.toString());
+                    result.append(compoundTypeName[i]);
                 }
+                return findType(result.toString());
+            }
 
-                private NameEnvironmentAnswer findType(String className) {
-
-                    if (className.equals(targetClassName)) {
-                        ICompilationUnit compilationUnit = new CompilationUnit(sourceFile, className);
-                        return new NameEnvironmentAnswer(compilationUnit, null);
-                    }
-
-                    String resourceName = className.replace('.', '/') + ".class";
-
-                    try (InputStream is = classLoader.getResourceAsStream(resourceName)) {
-                        if (is != null) {
-                            byte[] classBytes;
-                            byte[] buf = new byte[8192];
-                            ByteArrayOutputStream baos = new ByteArrayOutputStream(buf.length);
-                            int count;
-                            while ((count = is.read(buf, 0, buf.length)) > 0) {
-                                baos.write(buf, 0, count);
-                            }
-                            baos.flush();
-                            classBytes = baos.toByteArray();
-                            char[] fileName = className.toCharArray();
-                            ClassFileReader classFileReader = new ClassFileReader(classBytes, fileName, true);
-                            return new NameEnvironmentAnswer(classFileReader, null);
-                        }
-                    } catch (IOException | ClassFormatException exc) {
-                        log.error(Localizer.getMessage("jsp.error.compilation.dependent", className), exc);
-                    }
-                    return null;
-                }
-
-                private boolean isPackage(String result) {
-                    if (result.equals(targetClassName) || result.startsWith(targetClassName + '$')) {
-                        return false;
-                    }
-                    String resourceName = result.replace('.', '/') + ".class";
-                    try (InputStream is =
-                        classLoader.getResourceAsStream(resourceName)) {
-                        return is == null;
-                    } catch (IOException e) {
-                        // we are here, since close on is failed. That means it was not null
-                        return false;
-                    }
-                }
-
-                @Override
-                public boolean isPackage(char[][] parentPackageName, char[] packageName) {
-                    StringBuilder result = new StringBuilder();
-                    int i = 0;
-                    if (parentPackageName != null) {
-                        for (; i < parentPackageName.length; i++) {
-                            if (i > 0) {
-                                result.append('.');
-                            }
-                            result.append(parentPackageName[i]);
-                        }
-                    }
-
-                    if (Character.isUpperCase(packageName[0])) {
-                        if (!isPackage(result.toString())) {
-                            return false;
-                        }
-                    }
+            @Override
+            public NameEnvironmentAnswer findType(char[] typeName, char[][] packageName) {
+                StringBuilder result = new StringBuilder();
+                int i = 0;
+                for (; i < packageName.length; i++) {
                     if (i > 0) {
                         result.append('.');
                     }
-                    result.append(packageName);
+                    result.append(packageName[i]);
+                }
+                if (i > 0) {
+                    result.append('.');
+                }
+                result.append(typeName);
+                return findType(result.toString());
+            }
 
-                    return isPackage(result.toString());
+            private NameEnvironmentAnswer findType(String className) {
+
+                if (className.equals(targetClassName)) {
+                    ICompilationUnit compilationUnit = new CompilationUnit(sourceFile, className);
+                    return new NameEnvironmentAnswer(compilationUnit, null);
                 }
 
-                @Override
-                public void cleanup() {
+                String resourceName = className.replace('.', '/') + ".class";
+
+                try (InputStream is = classLoader.getResourceAsStream(resourceName)) {
+                    if (is != null) {
+                        byte[] classBytes;
+                        byte[] buf = new byte[8192];
+                        ByteArrayOutputStream baos = new ByteArrayOutputStream(buf.length);
+                        int count;
+                        while ((count = is.read(buf, 0, buf.length)) > 0) {
+                            baos.write(buf, 0, count);
+                        }
+                        baos.flush();
+                        classBytes = baos.toByteArray();
+                        char[] fileName = className.toCharArray();
+                        ClassFileReader classFileReader = new ClassFileReader(classBytes, fileName, true);
+                        return new NameEnvironmentAnswer(classFileReader, null);
+                    }
+                } catch (IOException | ClassFormatException exc) {
+                    log.error(Localizer.getMessage("jsp.error.compilation.dependent", className), exc);
+                }
+                return null;
+            }
+
+            private boolean isPackage(String result) {
+                if (result.equals(targetClassName) || result.startsWith(targetClassName + '$')) {
+                    return false;
+                }
+                String resourceName = result.replace('.', '/') + ".class";
+                try (InputStream is = classLoader.getResourceAsStream(resourceName)) {
+                    return is == null;
+                } catch (IOException e) {
+                    // we are here, since close on is failed. That means it was not null
+                    return false;
+                }
+            }
+
+            @Override
+            public boolean isPackage(char[][] parentPackageName, char[] packageName) {
+                StringBuilder result = new StringBuilder();
+                int i = 0;
+                if (parentPackageName != null) {
+                    for (; i < parentPackageName.length; i++) {
+                        if (i > 0) {
+                            result.append('.');
+                        }
+                        result.append(parentPackageName[i]);
+                    }
                 }
 
-            };
+                if (Character.isUpperCase(packageName[0])) {
+                    if (!isPackage(result.toString())) {
+                        return false;
+                    }
+                }
+                if (i > 0) {
+                    result.append('.');
+                }
+                result.append(packageName);
+
+                return isPackage(result.toString());
+            }
+
+            @Override
+            public void cleanup() {
+            }
+
+        };
 
         final IErrorHandlingPolicy policy = DefaultErrorHandlingPolicies.proceedWithAllProblems();
 
         final Map<String,String> settings = new HashMap<>();
-        settings.put(CompilerOptions.OPTION_LineNumberAttribute,
-                     CompilerOptions.GENERATE);
-        settings.put(CompilerOptions.OPTION_SourceFileAttribute,
-                     CompilerOptions.GENERATE);
-        settings.put(CompilerOptions.OPTION_ReportDeprecation,
-                     CompilerOptions.IGNORE);
+        settings.put(CompilerOptions.OPTION_LineNumberAttribute, CompilerOptions.GENERATE);
+        settings.put(CompilerOptions.OPTION_SourceFileAttribute, CompilerOptions.GENERATE);
+        settings.put(CompilerOptions.OPTION_ReportDeprecation, CompilerOptions.IGNORE);
         if (ctxt.getOptions().getJavaEncoding() != null) {
-            settings.put(CompilerOptions.OPTION_Encoding,
-                    ctxt.getOptions().getJavaEncoding());
+            settings.put(CompilerOptions.OPTION_Encoding, ctxt.getOptions().getJavaEncoding());
         }
         if (ctxt.getOptions().getClassDebugInfo()) {
-            settings.put(CompilerOptions.OPTION_LocalVariableAttribute,
-                         CompilerOptions.GENERATE);
+            settings.put(CompilerOptions.OPTION_LocalVariableAttribute, CompilerOptions.GENERATE);
         }
 
         // Source JVM
-        if(ctxt.getOptions().getCompilerSourceVM() != null) {
+        if (ctxt.getOptions().getCompilerSourceVM() != null) {
             String opt = ctxt.getOptions().getCompilerSourceVM();
-            if(opt.equals("1.1")) {
+            if (opt.equals("1.1")) {
                 settings.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_1_1);
-            } else if(opt.equals("1.2")) {
+            } else if (opt.equals("1.2")) {
                 settings.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_1_2);
-            } else if(opt.equals("1.3")) {
+            } else if (opt.equals("1.3")) {
                 settings.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_1_3);
-            } else if(opt.equals("1.4")) {
+            } else if (opt.equals("1.4")) {
                 settings.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_1_4);
-            } else if(opt.equals("1.5")) {
+            } else if (opt.equals("1.5")) {
                 settings.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_1_5);
-            } else if(opt.equals("1.6")) {
+            } else if (opt.equals("1.6")) {
                 settings.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_1_6);
-            } else if(opt.equals("1.7")) {
+            } else if (opt.equals("1.7")) {
                 settings.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_1_7);
-            } else if(opt.equals("1.8")) {
+            } else if (opt.equals("1.8")) {
                 settings.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_1_8);
-            // Version format changed from Java 9 onwards.
-            // Support old format that was used in EA implementation as well
-            } else if(opt.equals("9") || opt.equals("1.9")) {
+                // Version format changed from Java 9 onwards.
+                // Support old format that was used in EA implementation as well
+            } else if (opt.equals("9") || opt.equals("1.9")) {
                 settings.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_9);
-            } else if(opt.equals("10")) {
+            } else if (opt.equals("10")) {
                 settings.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_10);
-            } else if(opt.equals("11")) {
+            } else if (opt.equals("11")) {
                 settings.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_11);
-            } else if(opt.equals("12")) {
+            } else if (opt.equals("12")) {
                 settings.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_12);
-            } else if(opt.equals("13")) {
+            } else if (opt.equals("13")) {
                 settings.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_13);
-            } else if(opt.equals("14")) {
+            } else if (opt.equals("14")) {
                 settings.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_14);
-            } else if(opt.equals("15")) {
+            } else if (opt.equals("15")) {
                 settings.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_15);
-            } else if(opt.equals("16")) {
+            } else if (opt.equals("16")) {
                 settings.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_16);
-            } else if(opt.equals("17")) {
+            } else if (opt.equals("17")) {
                 settings.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_17);
-            } else if(opt.equals("18")) {
+            } else if (opt.equals("18")) {
                 settings.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_18);
             } else if (opt.equals("19")) {
                 settings.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_19);
@@ -349,58 +340,58 @@ public class JDTCompiler extends org.apache.jasper.compiler.Compiler {
         }
 
         // Target JVM
-        if(ctxt.getOptions().getCompilerTargetVM() != null) {
+        if (ctxt.getOptions().getCompilerTargetVM() != null) {
             String opt = ctxt.getOptions().getCompilerTargetVM();
-            if(opt.equals("1.1")) {
+            if (opt.equals("1.1")) {
                 settings.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_1_1);
-            } else if(opt.equals("1.2")) {
+            } else if (opt.equals("1.2")) {
                 settings.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_1_2);
-            } else if(opt.equals("1.3")) {
+            } else if (opt.equals("1.3")) {
                 settings.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_1_3);
-            } else if(opt.equals("1.4")) {
+            } else if (opt.equals("1.4")) {
                 settings.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_1_4);
-            } else if(opt.equals("1.5")) {
+            } else if (opt.equals("1.5")) {
                 settings.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_1_5);
                 settings.put(CompilerOptions.OPTION_Compliance, CompilerOptions.VERSION_1_5);
-            } else if(opt.equals("1.6")) {
+            } else if (opt.equals("1.6")) {
                 settings.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_1_6);
                 settings.put(CompilerOptions.OPTION_Compliance, CompilerOptions.VERSION_1_6);
-            } else if(opt.equals("1.7")) {
+            } else if (opt.equals("1.7")) {
                 settings.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_1_7);
                 settings.put(CompilerOptions.OPTION_Compliance, CompilerOptions.VERSION_1_7);
-            } else if(opt.equals("1.8")) {
+            } else if (opt.equals("1.8")) {
                 settings.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_1_8);
                 settings.put(CompilerOptions.OPTION_Compliance, CompilerOptions.VERSION_1_8);
-            // Version format changed from Java 9 onwards.
-            // Support old format that was used in EA implementation as well
-            } else if(opt.equals("9") || opt.equals("1.9")) {
+                // Version format changed from Java 9 onwards.
+                // Support old format that was used in EA implementation as well
+            } else if (opt.equals("9") || opt.equals("1.9")) {
                 settings.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_9);
                 settings.put(CompilerOptions.OPTION_Compliance, CompilerOptions.VERSION_9);
-            } else if(opt.equals("10")) {
+            } else if (opt.equals("10")) {
                 settings.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_10);
                 settings.put(CompilerOptions.OPTION_Compliance, CompilerOptions.VERSION_10);
-            } else if(opt.equals("11")) {
+            } else if (opt.equals("11")) {
                 settings.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_11);
                 settings.put(CompilerOptions.OPTION_Compliance, CompilerOptions.VERSION_11);
-            } else if(opt.equals("12")) {
+            } else if (opt.equals("12")) {
                 settings.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_12);
                 settings.put(CompilerOptions.OPTION_Compliance, CompilerOptions.VERSION_12);
-            } else if(opt.equals("13")) {
+            } else if (opt.equals("13")) {
                 settings.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_13);
                 settings.put(CompilerOptions.OPTION_Compliance, CompilerOptions.VERSION_13);
-            } else if(opt.equals("14")) {
+            } else if (opt.equals("14")) {
                 settings.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_14);
                 settings.put(CompilerOptions.OPTION_Compliance, CompilerOptions.VERSION_14);
-            } else if(opt.equals("15")) {
+            } else if (opt.equals("15")) {
                 settings.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_15);
                 settings.put(CompilerOptions.OPTION_Compliance, CompilerOptions.VERSION_15);
-            } else if(opt.equals("16")) {
+            } else if (opt.equals("16")) {
                 settings.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_16);
                 settings.put(CompilerOptions.OPTION_Compliance, CompilerOptions.VERSION_16);
-            } else if(opt.equals("17")) {
+            } else if (opt.equals("17")) {
                 settings.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_17);
                 settings.put(CompilerOptions.OPTION_Compliance, CompilerOptions.VERSION_17);
-            } else if(opt.equals("18")) {
+            } else if (opt.equals("18")) {
                 settings.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_18);
                 settings.put(CompilerOptions.OPTION_Compliance, CompilerOptions.VERSION_18);
             } else if (opt.equals("19")) {
@@ -449,54 +440,50 @@ public class JDTCompiler extends org.apache.jasper.compiler.Compiler {
         final IProblemFactory problemFactory = new DefaultProblemFactory(Locale.getDefault());
 
         final ICompilerRequestor requestor = new ICompilerRequestor() {
-                @Override
-                public void acceptResult(CompilationResult result) {
-                    try {
-                        if (result.hasProblems()) {
-                            IProblem[] problems = result.getProblems();
-                            for (IProblem problem : problems) {
-                                if (problem.isError()) {
-                                    String name =
-                                            new String(problem.getOriginatingFileName());
-                                    try {
-                                        problemList.add(ErrorDispatcher.createJavacError
-                                                (name, pageNodes, new StringBuilder(problem.getMessage()),
-                                                        problem.getSourceLineNumber(), ctxt));
-                                    } catch (JasperException e) {
-                                        log.error(Localizer.getMessage("jsp.error.compilation.jdtProblemError"), e);
-                                    }
+            @Override
+            public void acceptResult(CompilationResult result) {
+                try {
+                    if (result.hasProblems()) {
+                        IProblem[] problems = result.getProblems();
+                        for (IProblem problem : problems) {
+                            if (problem.isError()) {
+                                String name = new String(problem.getOriginatingFileName());
+                                try {
+                                    problemList.add(ErrorDispatcher.createJavacError(name, pageNodes,
+                                            new StringBuilder(problem.getMessage()), problem.getSourceLineNumber(),
+                                            ctxt));
+                                } catch (JasperException e) {
+                                    log.error(Localizer.getMessage("jsp.error.compilation.jdtProblemError"), e);
                                 }
                             }
                         }
-                        if (problemList.isEmpty()) {
-                            ClassFile[] classFiles = result.getClassFiles();
-                            for (ClassFile classFile : classFiles) {
-                                char[][] compoundName =
-                                        classFile.getCompoundName();
-                                StringBuilder classFileName = new StringBuilder(outputDir).append('/');
-                                for (int j = 0;
-                                     j < compoundName.length; j++) {
-                                    if (j > 0) {
-                                        classFileName.append('/');
-                                    }
-                                    classFileName.append(compoundName[j]);
-                                }
-                                byte[] bytes = classFile.getBytes();
-                                classFileName.append(".class");
-                                try (FileOutputStream fout = new FileOutputStream(classFileName.toString());
-                                        BufferedOutputStream bos = new BufferedOutputStream(fout)) {
-                                    bos.write(bytes);
-                                }
-                            }
-                        }
-                    } catch (IOException exc) {
-                        log.error(Localizer.getMessage("jsp.error.compilation.jdt"), exc);
                     }
+                    if (problemList.isEmpty()) {
+                        ClassFile[] classFiles = result.getClassFiles();
+                        for (ClassFile classFile : classFiles) {
+                            char[][] compoundName = classFile.getCompoundName();
+                            StringBuilder classFileName = new StringBuilder(outputDir).append('/');
+                            for (int j = 0; j < compoundName.length; j++) {
+                                if (j > 0) {
+                                    classFileName.append('/');
+                                }
+                                classFileName.append(compoundName[j]);
+                            }
+                            byte[] bytes = classFile.getBytes();
+                            classFileName.append(".class");
+                            try (FileOutputStream fout = new FileOutputStream(classFileName.toString());
+                                    BufferedOutputStream bos = new BufferedOutputStream(fout)) {
+                                bos.write(bytes);
+                            }
+                        }
+                    }
+                } catch (IOException exc) {
+                    log.error(Localizer.getMessage("jsp.error.compilation.jdt"), exc);
                 }
-            };
+            }
+        };
 
-        ICompilationUnit[] compilationUnits =
-            new ICompilationUnit[classNames.length];
+        ICompilationUnit[] compilationUnits = new ICompilationUnit[classNames.length];
         for (int i = 0; i < compilationUnits.length; i++) {
             String className = classNames[i];
             compilationUnits[i] = new CompilationUnit(fileNames[i], className);
@@ -522,29 +509,23 @@ public class JDTCompiler extends org.apache.jasper.compiler.Compiler {
         }
 
         cOptions.parseLiteralExpressionsAsConstants = true;
-        Compiler compiler = new Compiler(env,
-                                         policy,
-                                         cOptions,
-                                         requestor,
-                                         problemFactory);
+        Compiler compiler = new Compiler(env, policy, cOptions, requestor, problemFactory);
         compiler.compile(compilationUnits);
 
         if (!ctxt.keepGenerated()) {
             File javaFile = new File(ctxt.getServletJavaFileName());
             if (!javaFile.delete()) {
-                throw new JasperException(Localizer.getMessage(
-                        "jsp.warning.compiler.javafile.delete.fail", javaFile));
+                throw new JasperException(Localizer.getMessage("jsp.warning.compiler.javafile.delete.fail", javaFile));
             }
         }
 
         if (!problemList.isEmpty()) {
-            JavacErrorDetail[] jeds =
-                problemList.toArray(new JavacErrorDetail[0]);
+            JavacErrorDetail[] jeds = problemList.toArray(new JavacErrorDetail[0]);
             errDispatcher.javacError(jeds);
         }
 
-        if( log.isDebugEnabled() ) {
-            long t2=System.currentTimeMillis();
+        if (log.isDebugEnabled()) {
+            long t2 = System.currentTimeMillis();
             log.debug(Localizer.getMessage("jsp.compiled", ctxt.getServletJavaFileName(), Long.valueOf(t2 - t1)));
         }
 
@@ -553,7 +534,7 @@ public class JDTCompiler extends org.apache.jasper.compiler.Compiler {
         }
 
         // JSR45 Support
-        if (! options.isSmapSuppressed()) {
+        if (!options.isSmapSuppressed()) {
             SmapUtil.installSmap(smaps);
         }
     }
