@@ -21,7 +21,7 @@ import java.io.CharArrayWriter;
 import java.io.InputStream;
 import java.nio.charset.StandardCharsets;
 
-import javax.servlet.jsp.tagext.PageData;
+import jakarta.servlet.jsp.tagext.PageData;
 
 import org.apache.jasper.JasperException;
 import org.apache.tomcat.util.security.Escape;
@@ -29,13 +29,24 @@ import org.xml.sax.Attributes;
 import org.xml.sax.helpers.AttributesImpl;
 
 /**
- * An implementation of <code>javax.servlet.jsp.tagext.PageData</code> which builds the XML view of a given page. The
- * XML view is built in two passes: During the first pass, the FirstPassVisitor collects the attributes of the top-level
- * jsp:root and those of the jsp:root elements of any included pages, and adds them to the jsp:root element of the XML
- * view. In addition, any taglib directives are converted into xmlns: attributes and added to the jsp:root element of
- * the XML view. This pass ignores any nodes other than JspRoot and TaglibDirective. During the second pass, the
- * SecondPassVisitor produces the XML view, using the combined jsp:root attributes determined in the first pass and any
- * remaining pages nodes (this pass ignores any JspRoot and TaglibDirective nodes).
+ * An implementation of <code>jakarta.servlet.jsp.tagext.PageData</code> which
+ * builds the XML view of a given page.
+ *
+ * The XML view is built in two passes:
+ *
+ * During the first pass, the FirstPassVisitor collects the attributes of the
+ * top-level jsp:root and those of the jsp:root elements of any included
+ * pages, and adds them to the jsp:root element of the XML view.
+ * In addition, any taglib directives are converted into xmlns: attributes and
+ * added to the jsp:root element of the XML view.
+ * This pass ignores any nodes other than JspRoot and TaglibDirective.
+ *
+ * During the second pass, the SecondPassVisitor produces the XML view, using
+ * the combined jsp:root attributes determined in the first pass and any
+ * remaining pages nodes (this pass ignores any JspRoot and TaglibDirective
+ * nodes).
+ *
+ * @author Jan Luehe
  */
 class PageDataImpl extends PageData implements TagConstants {
 
@@ -47,20 +58,24 @@ class PageDataImpl extends PageData implements TagConstants {
     private final StringBuilder buf;
 
     /**
-     * @param page     the page nodes from which to generate the XML view
+     * @param page the page nodes from which to generate the XML view
      * @param compiler The compiler for this page
      *
      * @throws JasperException If an error occurs
      */
-    PageDataImpl(Node.Nodes page, Compiler compiler) throws JasperException {
+    PageDataImpl(Node.Nodes page, Compiler compiler)
+                throws JasperException {
 
         // First pass
-        FirstPassVisitor firstPass = new FirstPassVisitor(page.getRoot(), compiler.getPageInfo());
+        FirstPassVisitor firstPass = new FirstPassVisitor(page.getRoot(),
+                                                          compiler.getPageInfo());
         page.visit(firstPass);
 
         // Second pass
         buf = new StringBuilder();
-        SecondPassVisitor secondPass = new SecondPassVisitor(page.getRoot(), buf, compiler, firstPass.getJspIdPrefix());
+        SecondPassVisitor secondPass
+            = new SecondPassVisitor(page.getRoot(), buf, compiler,
+                                    firstPass.getJspIdPrefix());
         page.visit(secondPass);
     }
 
@@ -71,18 +86,22 @@ class PageDataImpl extends PageData implements TagConstants {
      */
     @Override
     public InputStream getInputStream() {
-        return new ByteArrayInputStream(buf.toString().getBytes(StandardCharsets.UTF_8));
+        return new ByteArrayInputStream(
+                buf.toString().getBytes(StandardCharsets.UTF_8));
     }
 
     /*
-     * First-pass Visitor for JspRoot nodes (representing jsp:root elements) and TaglibDirective nodes, ignoring any
-     * other nodes.
+     * First-pass Visitor for JspRoot nodes (representing jsp:root elements)
+     * and TablibDirective nodes, ignoring any other nodes.
      *
-     * The purpose of this Visitor is to collect the attributes of the top-level jsp:root and those of the jsp:root
-     * elements of any included pages, and add them to the jsp:root element of the XML view. In addition, this Visitor
-     * converts any taglib directives into xmlns: attributes and adds them to the jsp:root element of the XML view.
+     * The purpose of this Visitor is to collect the attributes of the
+     * top-level jsp:root and those of the jsp:root elements of any included
+     * pages, and add them to the jsp:root element of the XML view.
+     * In addition, this Visitor converts any taglib directives into xmlns:
+     * attributes and adds them to the jsp:root element of the XML view.
      */
-    private static class FirstPassVisitor extends Node.Visitor implements TagConstants {
+    private static class FirstPassVisitor
+                extends Node.Visitor implements TagConstants {
 
         private final Node.Root root;
         private final AttributesImpl rootAttrs;
@@ -98,7 +117,8 @@ class PageDataImpl extends PageData implements TagConstants {
             this.root = root;
             this.pageInfo = pageInfo;
             this.rootAttrs = new AttributesImpl();
-            this.rootAttrs.addAttribute("", "", "version", "CDATA", JSP_VERSION);
+            this.rootAttrs.addAttribute("", "", "version", "CDATA",
+                                        JSP_VERSION);
             this.jspIdPrefix = "jsp";
         }
 
@@ -109,23 +129,30 @@ class PageDataImpl extends PageData implements TagConstants {
                 /*
                  * Top-level page.
                  *
-                 * Add xmlns:jsp="http://java.sun.com/JSP/Page" attribute only if not already present.
+                 * Add
+                 *   xmlns:jsp="http://java.sun.com/JSP/Page"
+                 * attribute only if not already present.
                  */
                 if (!JSP_URI.equals(rootAttrs.getValue("xmlns:jsp"))) {
-                    rootAttrs.addAttribute("", "", "xmlns:jsp", "CDATA", JSP_URI);
+                    rootAttrs.addAttribute("", "", "xmlns:jsp", "CDATA",
+                                           JSP_URI);
                 }
 
                 if (pageInfo.isJspPrefixHijacked()) {
                     /*
-                     * 'jsp' prefix has been hijacked, that is, bound to a namespace other than the JSP namespace. This
-                     * means that when adding an 'id' attribute to each element, we can't use the 'jsp' prefix.
-                     * Therefore, create a new prefix (one that is unique across the translation unit) for use by the
-                     * 'id' attribute, and bind it to the JSP namespace
+                     * 'jsp' prefix has been hijacked, that is, bound to a
+                     * namespace other than the JSP namespace. This means that
+                     * when adding an 'id' attribute to each element, we can't
+                     * use the 'jsp' prefix. Therefore, create a new prefix
+                     * (one that is unique across the translation unit) for use
+                     * by the 'id' attribute, and bind it to the JSP namespace
                      */
-                    do {
+                    jspIdPrefix += "jsp";
+                    while (pageInfo.containsPrefix(jspIdPrefix)) {
                         jspIdPrefix += "jsp";
-                    } while (pageInfo.containsPrefix(jspIdPrefix));
-                    rootAttrs.addAttribute("", "", "xmlns:" + jspIdPrefix, "CDATA", JSP_URI);
+                    }
+                    rootAttrs.addAttribute("", "", "xmlns:" + jspIdPrefix,
+                                           "CDATA", JSP_URI);
                 }
 
                 root.setAttributes(rootAttrs);
@@ -142,7 +169,8 @@ class PageDataImpl extends PageData implements TagConstants {
         }
 
         /*
-         * Converts taglib directive into "xmlns:..." attribute of jsp:root element.
+         * Converts taglib directive into "xmlns:..." attribute of jsp:root
+         * element.
          */
         @Override
         public void visit(Node.TaglibDirective n) throws JasperException {
@@ -150,9 +178,10 @@ class PageDataImpl extends PageData implements TagConstants {
             if (attrs != null) {
                 String qName = "xmlns:" + attrs.getValue("prefix");
                 /*
-                 * According to javadocs of org.xml.sax.helpers.AttributesImpl, the addAttribute method does not check
-                 * to see if the specified attribute is already contained in the list: This is the application's
-                 * responsibility!
+                 * According to javadocs of org.xml.sax.helpers.AttributesImpl,
+                 * the addAttribute method does not check to see if the
+                 * specified attribute is already contained in the list: This
+                 * is the application's responsibility!
                  */
                 if (rootAttrs.getIndex(qName) == -1) {
                     String location = attrs.getValue("uri");
@@ -160,10 +189,12 @@ class PageDataImpl extends PageData implements TagConstants {
                         if (location.startsWith("/")) {
                             location = URN_JSPTLD + location;
                         }
-                        rootAttrs.addAttribute("", "", qName, "CDATA", location);
+                        rootAttrs.addAttribute("", "", qName, "CDATA",
+                                               location);
                     } else {
                         location = attrs.getValue("tagdir");
-                        rootAttrs.addAttribute("", "", qName, "CDATA", URN_JSPTAGDIR + location);
+                        rootAttrs.addAttribute("", "", qName, "CDATA",
+                                               URN_JSPTAGDIR + location);
                     }
                 }
             }
@@ -177,16 +208,19 @@ class PageDataImpl extends PageData implements TagConstants {
             if (attrs != null) {
                 int len = attrs.getLength();
 
-                for (int i = 0; i < len; i++) {
+                for (int i=0; i<len; i++) {
                     String qName = attrs.getQName(i);
                     if ("version".equals(qName)) {
                         continue;
                     }
 
                     // Bugzilla 35252: https://bz.apache.org/bugzilla/show_bug.cgi?id=35252
-                    if (rootAttrs.getIndex(qName) == -1) {
-                        rootAttrs.addAttribute(attrs.getURI(i), attrs.getLocalName(i), qName, attrs.getType(i),
-                                attrs.getValue(i));
+                    if(rootAttrs.getIndex(qName) == -1) {
+                        rootAttrs.addAttribute(attrs.getURI(i),
+                                               attrs.getLocalName(i),
+                                               qName,
+                                               attrs.getType(i),
+                                               attrs.getValue(i));
                     }
                 }
             }
@@ -195,9 +229,11 @@ class PageDataImpl extends PageData implements TagConstants {
 
 
     /*
-     * Second-pass Visitor responsible for producing XML view and assigning each element a unique jsp:id attribute.
+     * Second-pass Visitor responsible for producing XML view and assigning
+     * each element a unique jsp:id attribute.
      */
-    private static class SecondPassVisitor extends Node.Visitor implements TagConstants {
+    private static class SecondPassVisitor extends Node.Visitor
+                implements TagConstants {
 
         private final Node.Root root;
         private final StringBuilder buf;
@@ -211,7 +247,8 @@ class PageDataImpl extends PageData implements TagConstants {
         /*
          * Constructor
          */
-        SecondPassVisitor(Node.Root root, StringBuilder buf, Compiler compiler, String jspIdPrefix) {
+        SecondPassVisitor(Node.Root root, StringBuilder buf,
+                                 Compiler compiler, String jspIdPrefix) {
             this.root = root;
             this.buf = buf;
             this.compiler = compiler;
@@ -240,7 +277,8 @@ class PageDataImpl extends PageData implements TagConstants {
         /*
          * Visits jsp:root element of JSP page in XML syntax.
          *
-         * Any nested jsp:root elements (from pages included via an include directive) are ignored.
+         * Any nested jsp:root elements (from pages included via an
+         * include directive) are ignored.
          */
         @Override
         public void visit(Node.JspRoot n) throws JasperException {
@@ -403,8 +441,8 @@ class PageDataImpl extends PageData implements TagConstants {
         @Override
         public void visit(Node.TemplateText n) throws JasperException {
             /*
-             * If the template text came from a JSP page written in JSP syntax, create a jsp:text element for it (JSP
-             * 5.3.2).
+             * If the template text came from a JSP page written in JSP syntax,
+             * create a jsp:text element for it (JSP 5.3.2).
              */
             appendText(n.getText(), !n.getRoot().isXmlSyntax());
         }
@@ -417,10 +455,11 @@ class PageDataImpl extends PageData implements TagConstants {
         }
 
         /*
-         * Appends the given tag, including its body, to the XML view, and optionally reset default namespace to "", if
-         * none specified.
+         * Appends the given tag, including its body, to the XML view,
+         * and optionally reset default namespace to "", if none specified.
          */
-        private void appendTag(Node n, boolean addDefaultNS) throws JasperException {
+        private void appendTag(Node n, boolean addDefaultNS)
+                throws JasperException {
 
             Node.Nodes body = n.getBody();
             String text = n.getText();
@@ -432,7 +471,8 @@ class PageDataImpl extends PageData implements TagConstants {
             buf.append("  ").append(jspIdPrefix).append(":id").append("=\"");
             buf.append(jspId++).append("\"\n");
 
-            if (ROOT_ACTION.equals(n.getLocalName()) || body != null || text != null) {
+            if (ROOT_ACTION.equals(n.getLocalName()) || body != null
+                        || text != null) {
                 buf.append(">\n");
                 if (ROOT_ACTION.equals(n.getLocalName())) {
                     if (compiler.getCompilationContext().isTagFile()) {
@@ -446,30 +486,35 @@ class PageDataImpl extends PageData implements TagConstants {
                 } else {
                     appendText(text, false);
                 }
-                buf.append("</").append(n.getQName()).append(">\n");
+                buf.append("</" + n.getQName() + ">\n");
             } else {
                 buf.append("/>\n");
             }
         }
 
         /*
-         * Appends the page directive with the given attributes to the XML view.
+         * Appends the page directive with the given attributes to the XML
+         * view.
          *
-         * Since the import attribute of the page directive is the only page attribute that is allowed to appear
-         * multiple times within the same document, and since XML allows only single-value attributes, the values of
-         * multiple import attributes must be combined into one, separated by comma.
+         * Since the import attribute of the page directive is the only page
+         * attribute that is allowed to appear multiple times within the same
+         * document, and since XML allows only single-value attributes,
+         * the values of multiple import attributes must be combined into one,
+         * separated by comma.
          *
-         * If the given page directive contains just 'contentType' and/or 'pageEncoding' attributes, we ignore it, as
-         * we've already appended a page directive containing just these two attributes.
+         * If the given page directive contains just 'contentType' and/or
+         * 'pageEncoding' attributes, we ignore it, as we've already appended
+         * a page directive containing just these two attributes.
          */
         private void appendPageDirective(Node.PageDirective n) {
             boolean append = false;
             Attributes attrs = n.getAttributes();
             int len = (attrs == null) ? 0 : attrs.getLength();
-            for (int i = 0; i < len; i++) {
-                @SuppressWarnings("null") // If attrs==null, len == 0
+            for (int i=0; i<len; i++) {
+                @SuppressWarnings("null")  // If attrs==null, len == 0
                 String attrName = attrs.getQName(i);
-                if (!"pageEncoding".equals(attrName) && !"contentType".equals(attrName)) {
+                if (!"pageEncoding".equals(attrName)
+                        && !"contentType".equals(attrName)) {
                     append = true;
                     break;
                 }
@@ -486,14 +531,17 @@ class PageDataImpl extends PageData implements TagConstants {
             buf.append(jspId++).append("\"\n");
 
             // append remaining attributes
-            for (int i = 0; i < len; i++) {
-                @SuppressWarnings("null") // If attrs==null, len == 0
+            for (int i=0; i<len; i++) {
+                @SuppressWarnings("null")  // If attrs==null, len == 0
                 String attrName = attrs.getQName(i);
-                if ("import".equals(attrName) || "contentType".equals(attrName) || "pageEncoding".equals(attrName)) {
+                if ("import".equals(attrName) || "contentType".equals(attrName)
+                        || "pageEncoding".equals(attrName)) {
                     /*
-                     * Page directive's 'import' attribute is considered further down, and its 'pageEncoding' and
-                     * 'contentType' attributes are ignored, since we've already appended a new page directive
-                     * containing just these two attributes
+                     * Page directive's 'import' attribute is considered
+                     * further down, and its 'pageEncoding' and 'contentType'
+                     * attributes are ignored, since we've already appended
+                     * a new page directive containing just these two
+                     * attributes
                      */
                     continue;
                 }
@@ -501,7 +549,7 @@ class PageDataImpl extends PageData implements TagConstants {
                 buf.append("  ").append(attrName).append("=\"");
                 buf.append(JspUtil.getExprInXml(value)).append("\"\n");
             }
-            if (!n.getImports().isEmpty()) {
+            if (n.getImports().size() > 0) {
                 // Concatenate names of imported classes/packages
                 boolean first = true;
                 for (String i : n.getImports()) {
@@ -519,11 +567,13 @@ class PageDataImpl extends PageData implements TagConstants {
         }
 
         /*
-         * Appends a page directive with 'pageEncoding' and 'contentType' attributes.
+         * Appends a page directive with 'pageEncoding' and 'contentType'
+         * attributes.
          *
-         * The value of the 'pageEncoding' attribute is hard-coded to UTF-8, whereas the value of the 'contentType'
-         * attribute, which is identical to what the container will pass to ServletResponse.setContentType(), is derived
-         * from the pageInfo.
+         * The value of the 'pageEncoding' attribute is hard-coded
+         * to UTF-8, whereas the value of the 'contentType' attribute, which
+         * is identical to what the container will pass to
+         * ServletResponse.setContentType(), is derived from the pageInfo.
          */
         private void appendPageDirective() {
             buf.append('<').append(JSP_PAGE_DIRECTIVE_ACTION);
@@ -539,18 +589,21 @@ class PageDataImpl extends PageData implements TagConstants {
         }
 
         /*
-         * Appends the tag directive with the given attributes to the XML view.
+         * Appends the tag directive with the given attributes to the XML
+         * view.
          *
-         * If the given tag directive contains just a 'pageEncoding' attributes, we ignore it, as we've already appended
+         * If the given tag directive contains just a 'pageEncoding'
+         * attributes, we ignore it, as we've already appended
          * a tag directive containing just this attributes.
          */
-        private void appendTagDirective(Node.TagDirective n) throws JasperException {
+        private void appendTagDirective(Node.TagDirective n)
+                throws JasperException {
 
             boolean append = false;
             Attributes attrs = n.getAttributes();
             int len = (attrs == null) ? 0 : attrs.getLength();
-            for (int i = 0; i < len; i++) {
-                @SuppressWarnings("null") // If attrs==null, len == 0
+            for (int i=0; i<len; i++) {
+                @SuppressWarnings("null")  // If attrs==null, len == 0
                 String attrName = attrs.getQName(i);
                 if (!"pageEncoding".equals(attrName)) {
                     append = true;
@@ -565,7 +618,8 @@ class PageDataImpl extends PageData implements TagConstants {
         }
 
         /*
-         * Appends a tag directive containing a single 'pageEncoding' attribute whose value is hard-coded to UTF-8.
+         * Appends a tag directive containing a single 'pageEncoding'
+         * attribute whose value is hard-coded to UTF-8.
          */
         private void appendTagDirective() {
             buf.append('<').append(JSP_TAG_DIRECTIVE_ACTION);
@@ -597,7 +651,8 @@ class PageDataImpl extends PageData implements TagConstants {
         }
 
         /*
-         * Appends the given text as a CDATA section to the XML view, unless the text has already been marked as CDATA.
+         * Appends the given text as a CDATA section to the XML view, unless
+         * the text has already been marked as CDATA.
          */
         private void appendCDATA(String text) {
             buf.append(CDATA_START_SECTION);
@@ -606,18 +661,20 @@ class PageDataImpl extends PageData implements TagConstants {
         }
 
         /*
-         * Escapes any occurrences of "]]>" (by replacing them with "]]&gt;") within the given text, so it can be
-         * included in a CDATA section.
+         * Escapes any occurrences of "]]>" (by replacing them with "]]&gt;")
+         * within the given text, so it can be included in a CDATA section.
          */
         private String escapeCDATA(String text) {
-            if (text == null) {
+            if( text==null ) {
                 return "";
             }
             int len = text.length();
             CharArrayWriter result = new CharArrayWriter(len);
-            for (int i = 0; i < len; i++) {
-                if (((i + 2) < len) && (text.charAt(i) == ']') && (text.charAt(i + 1) == ']') &&
-                        (text.charAt(i + 2) == '>')) {
+            for (int i=0; i<len; i++) {
+                if (((i+2) < len)
+                        && (text.charAt(i) == ']')
+                        && (text.charAt(i+1) == ']')
+                        && (text.charAt(i+2) == '>')) {
                     // match found
                     result.write(']');
                     result.write(']');
@@ -643,8 +700,8 @@ class PageDataImpl extends PageData implements TagConstants {
              */
             Attributes attrs = n.getTaglibAttributes();
             int len = (attrs == null) ? 0 : attrs.getLength();
-            for (int i = 0; i < len; i++) {
-                @SuppressWarnings("null") // If attrs==null, len == 0
+            for (int i=0; i<len; i++) {
+                @SuppressWarnings("null")  // If attrs==null, len == 0
                 String name = attrs.getQName(i);
                 String value = attrs.getValue(i);
                 buf.append("  ").append(name).append("=\"").append(value).append("\"\n");
@@ -656,8 +713,8 @@ class PageDataImpl extends PageData implements TagConstants {
             attrs = n.getNonTaglibXmlnsAttributes();
             len = (attrs == null) ? 0 : attrs.getLength();
             boolean defaultNSSeen = false;
-            for (int i = 0; i < len; i++) {
-                @SuppressWarnings("null") // If attrs==null, len == 0
+            for (int i=0; i<len; i++) {
+                @SuppressWarnings("null")  // If attrs==null, len == 0
                 String name = attrs.getQName(i);
                 String value = attrs.getValue(i);
                 buf.append("  ").append(name).append("=\"").append(value).append("\"\n");
@@ -673,8 +730,8 @@ class PageDataImpl extends PageData implements TagConstants {
              */
             attrs = n.getAttributes();
             len = (attrs == null) ? 0 : attrs.getLength();
-            for (int i = 0; i < len; i++) {
-                @SuppressWarnings("null") // If attrs==null, len == 0
+            for (int i=0; i<len; i++) {
+                @SuppressWarnings("null")  // If attrs==null, len == 0
                 String name = attrs.getQName(i);
                 String value = attrs.getValue(i);
                 buf.append("  ").append(name).append("=\"");
