@@ -20,6 +20,7 @@ import java.beans.FeatureDescriptor;
 import java.lang.reflect.Method;
 import java.util.Iterator;
 import java.util.List;
+import java.util.Objects;
 import java.util.concurrent.atomic.AtomicInteger;
 
 import jakarta.el.ArrayELResolver;
@@ -198,6 +199,10 @@ public class JasperELResolver extends CompositeELResolver {
         @Override
         public Object getValue(ELContext context, Object base,
                 Object property) {
+            Objects.requireNonNull(context);
+            if (base == null || property == null) {
+                return null;
+            }
             Object value = null;
             Method method = getReadMethod(base.getClass(), property.toString());
             if (method != null) {
@@ -216,7 +221,8 @@ public class JasperELResolver extends CompositeELResolver {
         @Override
         public void setValue(ELContext context, Object base, Object property,
                 Object value) {
-            if (base == null) {
+            Objects.requireNonNull(context);
+            if (base == null || property == null) {
                 return;
             }
             Method method = getWriteMethod(base.getClass(), property.toString(), value.getClass());
@@ -234,6 +240,10 @@ public class JasperELResolver extends CompositeELResolver {
         @Override
         public boolean isReadOnly(ELContext context, Object base,
                 Object property) {
+            Objects.requireNonNull(context);
+            if (base == null || property == null) {
+                return false;
+            }
             Class<?> beanClass = base.getClass();
             String prop = property.toString();
             Method readMethod = getReadMethod(beanClass, prop);
@@ -291,6 +301,9 @@ public class JasperELResolver extends CompositeELResolver {
 
         @Override
         public Class<?> getCommonPropertyType(ELContext context, Object base) {
+            if (base != null) {
+                return Object.class;
+            }
             return null;
         }
     }
