@@ -24,6 +24,7 @@ import java.lang.management.ThreadInfo;
 import java.lang.management.ThreadMXBean;
 import java.util.LinkedHashMap;
 import java.util.Map;
+import java.util.Map.Entry;
 import java.util.logging.Formatter;
 import java.util.logging.LogManager;
 import java.util.logging.LogRecord;
@@ -41,8 +42,8 @@ public class OneLineFormatter extends Formatter {
     private static final Object threadMxBeanLock = new Object();
     private static volatile ThreadMXBean threadMxBean = null;
     private static final int THREAD_NAME_CACHE_SIZE = 10000;
-    private static final ThreadLocal<ThreadNameCache> threadNameCache =
-            ThreadLocal.withInitial(() -> new ThreadNameCache(THREAD_NAME_CACHE_SIZE));
+    private static final ThreadLocal<ThreadNameCache> threadNameCache = ThreadLocal
+            .withInitial(() -> new ThreadNameCache(THREAD_NAME_CACHE_SIZE));
 
     /* Timestamp format */
     private static final String DEFAULT_TIME_FORMAT = "dd-MMM-yyyy HH:mm:ss.SSS";
@@ -100,8 +101,8 @@ public class OneLineFormatter extends Formatter {
         }
 
         final DateFormatCache globalDateCache = new DateFormatCache(globalCacheSize, cachedTimeFormat, null);
-        localDateCache =
-                ThreadLocal.withInitial(() -> new DateFormatCache(localCacheSize, cachedTimeFormat, globalDateCache));
+        localDateCache = ThreadLocal
+                .withInitial(() -> new DateFormatCache(localCacheSize, cachedTimeFormat, globalDateCache));
     }
 
 
@@ -213,13 +214,9 @@ public class OneLineFormatter extends Formatter {
      * <p>
      * Words fail me to describe what I think of the design decision to use an int in LogRecord for a long value and the
      * resulting mess that follows.
-     *
-     * @param logRecordThreadId the thread id
-     *
-     * @return the thread name
      */
-    protected static String getThreadName(int logRecordThreadId) {
-        Map<Integer,String> cache = threadNameCache.get();
+    private static String getThreadName(int logRecordThreadId) {
+        Map<Integer, String> cache = threadNameCache.get();
         String result = cache.get(Integer.valueOf(logRecordThreadId));
 
         if (result != null) {
@@ -253,7 +250,7 @@ public class OneLineFormatter extends Formatter {
     /*
      * This is an LRU cache.
      */
-    private static class ThreadNameCache extends LinkedHashMap<Integer,String> {
+    private static class ThreadNameCache extends LinkedHashMap<Integer, String> {
 
         private static final long serialVersionUID = 1L;
 
@@ -265,7 +262,7 @@ public class OneLineFormatter extends Formatter {
         }
 
         @Override
-        protected boolean removeEldestEntry(Map.Entry<Integer,String> eldest) {
+        protected boolean removeEldestEntry(Entry<Integer, String> eldest) {
             return (size() > cacheSize);
         }
     }
@@ -290,10 +287,6 @@ public class OneLineFormatter extends Formatter {
 
 
     private enum MillisHandling {
-        NONE,
-        APPEND,
-        REPLACE_S,
-        REPLACE_SS,
-        REPLACE_SSS,
+        NONE, APPEND, REPLACE_S, REPLACE_SS, REPLACE_SSS,
     }
 }
