@@ -25,15 +25,16 @@ import javax.naming.Context;
 import javax.naming.Name;
 import javax.naming.NamingException;
 import javax.naming.RefAddr;
+import javax.naming.Reference;
 import javax.naming.spi.ObjectFactory;
 
 import org.apache.naming.ResourceLinkRef;
 import org.apache.naming.StringManager;
 
 /**
- * <p>
- * Object factory for resource links.
- * </p>
+ * <p>Object factory for resource links.</p>
+ *
+ * @author Remy Maucherat
  */
 public class ResourceLinkFactory implements ObjectFactory {
 
@@ -46,7 +47,8 @@ public class ResourceLinkFactory implements ObjectFactory {
      */
     private static Context globalContext = null;
 
-    private static final Map<ClassLoader,Map<String,String>> globalResourceRegistrations = new ConcurrentHashMap<>();
+    private static Map<ClassLoader,Map<String,String>> globalResourceRegistrations =
+            new ConcurrentHashMap<>();
 
     // --------------------------------------------------------- Public Methods
 
@@ -58,13 +60,15 @@ public class ResourceLinkFactory implements ObjectFactory {
     public static void setGlobalContext(Context newGlobalContext) {
         SecurityManager sm = System.getSecurityManager();
         if (sm != null) {
-            sm.checkPermission(new RuntimePermission(ResourceLinkFactory.class.getName() + ".setGlobalContext"));
+            sm.checkPermission(new RuntimePermission(
+                   ResourceLinkFactory.class.getName() + ".setGlobalContext"));
         }
         globalContext = newGlobalContext;
     }
 
 
-    public static void registerGlobalResourceAccess(Context globalContext, String localName, String globalName) {
+    public static void registerGlobalResourceAccess(Context globalContext, String localName,
+            String globalName) {
         validateGlobalContext(globalContext);
         ClassLoader cl = Thread.currentThread().getContextClassLoader();
         // Web application initialization is single threaded so this is
@@ -91,7 +95,8 @@ public class ResourceLinkFactory implements ObjectFactory {
 
 
     private static void validateGlobalContext(Context globalContext) {
-        if (ResourceLinkFactory.globalContext != null && ResourceLinkFactory.globalContext != globalContext) {
+        if (ResourceLinkFactory.globalContext != null &&
+                ResourceLinkFactory.globalContext != globalContext) {
             throw new SecurityException(sm.getString("resourceLinkFactory.invalidGlobalContext"));
         }
     }
@@ -115,27 +120,25 @@ public class ResourceLinkFactory implements ObjectFactory {
     /**
      * Create a new resource instance.
      *
-     * @param name        the bound name
-     * @param nameCtx     unused
+     * @param name the bound name
+     * @param nameCtx unused
      * @param environment unused
-     *
      * @return the object instance
-     *
      * @throws NamingException if an error occur creating the instance
      */
     @Override
-    public Object getObjectInstance(Object obj, Name name, Context nameCtx, Hashtable<?,?> environment)
-            throws NamingException {
+    public Object getObjectInstance(Object obj, Name name, Context nameCtx,
+            Hashtable<?,?> environment) throws NamingException {
 
         if (!(obj instanceof ResourceLinkRef)) {
             return null;
         }
 
         // Can we process this request?
-        ResourceLinkRef ref = (ResourceLinkRef) obj;
+        Reference ref = (Reference) obj;
 
         // Read the global ref addr
-        String globalName;
+        String globalName = null;
         RefAddr refAddr = ref.get(ResourceLinkRef.GLOBALNAME);
         if (refAddr != null) {
             globalName = refAddr.getContent().toString();
@@ -144,22 +147,24 @@ public class ResourceLinkFactory implements ObjectFactory {
             if (!validateGlobalResourceAccess(globalName)) {
                 return null;
             }
-            Object result = globalContext.lookup(globalName);
+            Object result = null;
+            result = globalContext.lookup(globalName);
             // Check the expected type
             String expectedClassName = ref.getClassName();
             if (expectedClassName == null) {
-                throw new IllegalArgumentException(sm.getString("resourceLinkFactory.nullType", name, globalName));
+                throw new IllegalArgumentException(
+                        sm.getString("resourceLinkFactory.nullType", name, globalName));
             }
             try {
-                Class<?> expectedClazz =
-                        Class.forName(expectedClassName, true, Thread.currentThread().getContextClassLoader());
+                Class<?> expectedClazz = Class.forName(
+                        expectedClassName, true, Thread.currentThread().getContextClassLoader());
                 if (!expectedClazz.isAssignableFrom(result.getClass())) {
-                    throw new IllegalArgumentException(sm.getString("resourceLinkFactory.wrongType", name, globalName,
-                            expectedClassName, result.getClass().getName()));
+                    throw new IllegalArgumentException(sm.getString("resourceLinkFactory.wrongType",
+                            name, globalName, expectedClassName, result.getClass().getName()));
                 }
             } catch (ClassNotFoundException e) {
-                throw new IllegalArgumentException(
-                        sm.getString("resourceLinkFactory.unknownType", name, globalName, expectedClassName), e);
+                throw new IllegalArgumentException(sm.getString("resourceLinkFactory.unknownType",
+                        name, globalName, expectedClassName), e);
             }
             return result;
         }
