@@ -18,6 +18,8 @@ package org.apache.tomcat.dbcp.pool2;
 
 import java.io.Closeable;
 import java.util.Collection;
+import java.util.Collections;
+import java.util.List;
 import java.util.NoSuchElementException;
 
 /**
@@ -35,14 +37,14 @@ import java.util.NoSuchElementException;
  * <code style="color:#00C">try</code> {
  *     obj = pool.borrowObject(key);
  *     <code style="color:#0C0">//...use the object...</code>
- * } <code style="color:#00C">catch</code>(Exception e) {
+ * } <code style="color:#00C">catch</code> (Exception e) {
  *     <code style="color:#0C0">// invalidate the object</code>
  *     pool.invalidateObject(key, obj);
  *     <code style="color:#0C0">// do not return the object to the pool twice</code>
  *     obj = <code style="color:#00C">null</code>;
  * } <code style="color:#00C">finally</code> {
  *     <code style="color:#0C0">// make sure the object is returned to the pool</code>
- *     <code style="color:#00C">if</code>(<code style="color:#00C">null</code> != obj) {
+ *     <code style="color:#00C">if</code> (<code style="color:#00C">null</code> != obj) {
  *         pool.returnObject(key, obj);
  *     }
  * }</pre>
@@ -60,6 +62,7 @@ import java.util.NoSuchElementException;
  * @param <K> The type of keys maintained by this pool.
  * @param <V> Type of element pooled in this pool.
  *
+ *
  * @see KeyedPooledObjectFactory
  * @see ObjectPool
  * @see org.apache.tomcat.dbcp.pool2.impl.GenericKeyedObjectPool GenericKeyedObjectPool
@@ -69,7 +72,7 @@ import java.util.NoSuchElementException;
 public interface KeyedObjectPool<K, V> extends Closeable {
 
     /**
-     * Create an object using the {@link KeyedPooledObjectFactory factory} or
+     * Creates an object using the {@link KeyedPooledObjectFactory factory} or
      * other implementation dependent mechanism, passivate it, and then place it
      * in the idle object pool. {@code addObject} is useful for
      * "pre-loading" a pool with idle objects (Optional operation).
@@ -83,8 +86,7 @@ public interface KeyedObjectPool<K, V> extends Closeable {
      * @throws UnsupportedOperationException
      *              when this pool cannot add new idle objects.
      */
-    void addObject(K key) throws Exception, IllegalStateException,
-            UnsupportedOperationException;
+    void addObject(K key) throws Exception;
 
     /**
      * Calls {@link KeyedObjectPool#addObject(Object)} with each
@@ -103,11 +105,11 @@ public interface KeyedObjectPool<K, V> extends Closeable {
      *             in {@code keys} is {@code null}.
      * @see #addObjects(Object, int)
      */
-    default void addObjects(final Collection<K> keys, final int count) throws Exception, IllegalArgumentException {
+    default void addObjects(final Collection<K> keys, final int count) throws Exception {
         if (keys == null) {
             throw new IllegalArgumentException(PoolUtils.MSG_NULL_KEYS);
         }
-        for (K key : keys) {
+        for (final K key : keys) {
             addObjects(key, count);
         }
     }
@@ -126,7 +128,7 @@ public interface KeyedObjectPool<K, V> extends Closeable {
      *             when {@code key} is {@code null}.
      * @since 2.8.0
      */
-    default void addObjects(final K key, final int count) throws Exception, IllegalArgumentException {
+    default void addObjects(final K key, final int count) throws Exception {
         if (key == null) {
             throw new IllegalArgumentException(PoolUtils.MSG_NULL_KEY);
         }
@@ -136,7 +138,7 @@ public interface KeyedObjectPool<K, V> extends Closeable {
     }
 
     /**
-     * Obtains an instance from this pool for the specified {@code key}.
+     * Borrows an instance from this pool for the specified {@code key}.
      * <p>
      * Instances returned from this method will have been either newly created
      * with {@link KeyedPooledObjectFactory#makeObject makeObject} or will be
@@ -171,7 +173,7 @@ public interface KeyedObjectPool<K, V> extends Closeable {
      *              when the pool is exhausted and cannot or will not return
      *              another instance
      */
-    V borrowObject(K key) throws Exception, NoSuchElementException, IllegalStateException;
+    V borrowObject(K key) throws Exception;
 
     /**
      * Clears the pool, removing all pooled instances (optional operation).
@@ -181,7 +183,7 @@ public interface KeyedObjectPool<K, V> extends Closeable {
      *
      * @throws Exception if the pool cannot be cleared
      */
-    void clear() throws Exception, UnsupportedOperationException;
+    void clear() throws Exception;
 
     /**
      * Clears the specified pool, removing all pooled instances corresponding to
@@ -194,10 +196,10 @@ public interface KeyedObjectPool<K, V> extends Closeable {
      *
      * @throws Exception if the key cannot be cleared
      */
-    void clear(K key) throws Exception, UnsupportedOperationException;
+    void clear(K key) throws Exception;
 
     /**
-     * Close this pool, and free any resources associated with it.
+     * Closes this pool, and free any resources associated with it.
      * <p>
      * Calling {@link #addObject addObject} or
      * {@link #borrowObject borrowObject} after invoking this method on a pool
@@ -211,7 +213,21 @@ public interface KeyedObjectPool<K, V> extends Closeable {
     void close();
 
     /**
-     * Returns the total number of instances currently borrowed from this pool but
+     * Gets a copy of the pool key list.
+     * <p>
+     * Note: The default implementation returns an empty list.
+     * Implementations should override this method.
+     * </p>
+     *
+     * @return a copy of the pool key list.
+     * @since 2.12.0
+     */
+    default List<K> getKeys() {
+        return Collections.emptyList();
+    }
+
+    /**
+     * Gets the total number of instances currently borrowed from this pool but
      * not yet returned. Returns a negative value if this information is not
      * available.
      * @return the total number of instances currently borrowed from this pool but
@@ -220,7 +236,7 @@ public interface KeyedObjectPool<K, V> extends Closeable {
     int getNumActive();
 
     /**
-     * Returns the number of instances currently borrowed from but not yet
+     * Gets the number of instances currently borrowed from but not yet
      * returned to the pool corresponding to the given {@code key}.
      * Returns a negative value if this information is not available.
      *
@@ -231,14 +247,14 @@ public interface KeyedObjectPool<K, V> extends Closeable {
     int getNumActive(K key);
 
     /**
-     * Returns the total number of instances currently idle in this pool.
+     * Gets the total number of instances currently idle in this pool.
      * Returns a negative value if this information is not available.
      * @return the total number of instances currently idle in this pool.
      */
     int getNumIdle();
 
     /**
-     * Returns the number of instances corresponding to the given
+     * Gets the number of instances corresponding to the given
      * {@code key} currently idle in this pool. Returns a negative value if
      * this information is not available.
      *
@@ -269,6 +285,32 @@ public interface KeyedObjectPool<K, V> extends Closeable {
      */
     void invalidateObject(K key, V obj) throws Exception;
 
+    /**
+     * Invalidates an object from the pool, using the provided
+     * {@link DestroyMode}.
+     * <p>
+     * By contract, {@code obj} <strong>must</strong> have been obtained
+     * using {@link #borrowObject borrowObject} or a related method as defined
+     * in an implementation or sub-interface using a {@code key} that is
+     * equivalent to the one used to borrow the {@code Object} in the first
+     * place.
+     * </p>
+     * <p>
+     * This method should be used when an object that has been borrowed is
+     * determined (due to an exception or other problem) to be invalid.
+     * </p>
+     *
+     * @param key the key used to obtain the object
+     * @param obj a {@link #borrowObject borrowed} instance to be returned.
+     * @param destroyMode destroy activation context provided to the factory
+     *
+     * @throws Exception if the instance cannot be invalidated
+     * @since 2.9.0
+     */
+    default void invalidateObject(final K key, final V obj, final DestroyMode destroyMode) throws Exception {
+        invalidateObject(key, obj);
+    }
+
     /**
      * Return an instance to the pool. By contract, {@code obj}
      * <strong>must</strong> have been obtained using
