@@ -20,6 +20,11 @@ import java.lang.reflect.Field;
 import java.net.SocketAddress;
 import java.nio.channels.ServerSocketChannel;
 import java.nio.channels.SocketChannel;
+import java.security.PrivilegedExceptionAction;
+import java.util.concurrent.Callable;
+import java.util.concurrent.CompletionException;
+
+import javax.security.auth.Subject;
 
 import org.apache.tomcat.util.res.StringManager;
 
@@ -151,21 +156,15 @@ public class JreCompat {
     /**
      * Obtains the executor, if any, used to create the provided thread.
      *
-     * @param thread    The thread to examine
+     * @param thread The thread to examine
      *
-     * @return  The executor, if any, that created the provided thread
+     * @return The executor, if any, that created the provided thread
      *
-     * @throws NoSuchFieldException
-     *              If a field used via reflection to obtain the executor cannot
-     *              be found
-     * @throws SecurityException
-     *              If a security exception occurs while trying to identify the
-     *              executor
-     * @throws IllegalArgumentException
-     *              If the instance object does not match the class of the field
-     *              when obtaining a field value via reflection
-     * @throws IllegalAccessException
-     *              If a field is not accessible due to access restrictions
+     * @throws NoSuchFieldException     If a field used via reflection to obtain the executor cannot be found
+     * @throws SecurityException        If a security exception occurs while trying to identify the executor
+     * @throws IllegalArgumentException If the instance object does not match the class of the field when obtaining a
+     *                                      field value via reflection
+     * @throws IllegalAccessException   If a field is not accessible due to access restrictions
      */
     public Object getExecutor(Thread thread)
             throws NoSuchFieldException, SecurityException, IllegalArgumentException, IllegalAccessException {
@@ -191,11 +190,9 @@ public class JreCompat {
         // "java.util.concurrent" code is in public domain,
         // so all implementations are similar including our
         // internal fork.
-        if (target != null && target.getClass().getCanonicalName() != null &&
-                (target.getClass().getCanonicalName().equals(
-                        "org.apache.tomcat.util.threads.ThreadPoolExecutor.Worker") ||
-                        target.getClass().getCanonicalName().equals(
-                                "java.util.concurrent.ThreadPoolExecutor.Worker"))) {
+        if (target != null && target.getClass().getCanonicalName() != null && (target.getClass().getCanonicalName()
+                .equals("org.apache.tomcat.util.threads.ThreadPoolExecutor.Worker") ||
+                target.getClass().getCanonicalName().equals("java.util.concurrent.ThreadPoolExecutor.Worker"))) {
             Field executorField = target.getClass().getDeclaredField("this$0");
             executorField.setAccessible(true);
             result = executorField.get(target);
@@ -228,4 +225,37 @@ public class JreCompat {
     public void threadBuilderStart(Object threadBuilder, Runnable command) {
         throw new UnsupportedOperationException(sm.getString("jreCompat.noVirtualThreads"));
     }
+
+
+    /*
+     * This is a slightly different usage of JreCompat.
+     *
+     * Subject.doAs() was deprecated in Java 18 and replaced with Subject.callAs(). As of Java 23, calling
+     * Subject.doAs() will trigger an UnsupportedOperationException unless the java.security.manager system property is
+     * set. To avoid Tomcat installations using Spnego authentication having to set this value, JreCompat is used to
+     * call Subject.callAs() instead.
+     *
+     * Because Java versions 18 to 22 inclusive support both the old and the new method, the switch over can occur at
+     * any Java version from 18 to 22 inclusive. Java 21 onwards was selected as it as an LTS version and that removes
+     * the need to add a Jre18Compat class.
+     *
+     * So, the slightly longer description for this method is:
+     *
+     * Java 11 implementation of a method replaced between Java 18 and 22 with the replacement method being used by
+     * Tomcat when running on Java 21 onwards.
+     */
+
+    public <T> T callAs(Subject subject, Callable<T> action) throws CompletionException {
+        try {
+            return Subject.doAs(subject, new PrivilegedExceptionAction<T>() {
+
+                @Override
+                public T run() throws Exception {
+                    return action.call();
+                }
+            });
+        } catch (Exception e) {
+            throw new CompletionException(e);
+        }
+    }
 }
