@@ -34,10 +34,14 @@ import org.xml.sax.ext.EntityResolver2;
  */
 public class LocalResolver implements EntityResolver2 {
 
-    private static final StringManager sm = StringManager.getManager(Constants.PACKAGE_NAME);
+    private static final StringManager sm =
+            StringManager.getManager(Constants.PACKAGE_NAME);
 
-    private static final String[] JAVA_EE_NAMESPACES =
-            { XmlIdentifiers.JAVAEE_1_4_NS, XmlIdentifiers.JAVAEE_5_NS, XmlIdentifiers.JAVAEE_7_NS };
+    private static final String[] JAVA_EE_NAMESPACES = {
+        XmlIdentifiers.JAVAEE_1_4_NS,
+        XmlIdentifiers.JAVAEE_5_NS,
+        XmlIdentifiers.JAVAEE_7_NS,
+        XmlIdentifiers.JAKARTAEE_9_NS};
 
 
     private final Map<String,String> publicIds;
@@ -45,14 +49,19 @@ public class LocalResolver implements EntityResolver2 {
     private final boolean blockExternal;
 
     /**
-     * Constructor providing mappings of public and system identifiers to local resources. Each map contains a mapping
-     * from a well-known identifier to a URL for a local resource path.
+     * Constructor providing mappings of public and system identifiers to local
+     * resources. Each map contains a mapping from a well-known identifier to a
+     * URL for a local resource path.
      *
-     * @param publicIds     mapping of well-known public identifiers to local resources
-     * @param systemIds     mapping of well-known system identifiers to local resources
-     * @param blockExternal are external resources blocked that are not well-known
+     * @param publicIds mapping of well-known public identifiers to local
+     *                  resources
+     * @param systemIds mapping of well-known system identifiers to local
+     *                  resources
+     * @param blockExternal are external resources blocked that are not
+     *                      well-known
      */
-    public LocalResolver(Map<String,String> publicIds, Map<String,String> systemIds, boolean blockExternal) {
+    public LocalResolver(Map<String,String> publicIds,
+            Map<String,String> systemIds, boolean blockExternal) {
         this.publicIds = publicIds;
         this.systemIds = systemIds;
         this.blockExternal = blockExternal;
@@ -60,14 +69,15 @@ public class LocalResolver implements EntityResolver2 {
 
 
     @Override
-    public InputSource resolveEntity(String publicId, String systemId) throws SAXException, IOException {
+    public InputSource resolveEntity(String publicId, String systemId)
+            throws SAXException, IOException {
         return resolveEntity(null, publicId, null, systemId);
     }
 
 
     @Override
-    public InputSource resolveEntity(String name, String publicId, String base, String systemId)
-            throws SAXException, IOException {
+    public InputSource resolveEntity(String name, String publicId,
+            String base, String systemId) throws SAXException, IOException {
 
         // First try resolving using the publicId
         String resolved = publicIds.get(publicId);
@@ -79,7 +89,8 @@ public class LocalResolver implements EntityResolver2 {
 
         // If there is no systemId, can't try anything else
         if (systemId == null) {
-            throw new FileNotFoundException(sm.getString("localResolver.unresolvedEntity", name, publicId, null, base));
+            throw new FileNotFoundException(sm.getString("localResolver.unresolvedEntity",
+                    name, publicId, null, base));
         }
 
         // Try resolving with the supplied systemId
@@ -138,12 +149,14 @@ public class LocalResolver implements EntityResolver2 {
             }
         }
 
-        throw new FileNotFoundException(sm.getString("localResolver.unresolvedEntity", name, publicId, systemId, base));
+        throw new FileNotFoundException(sm.getString("localResolver.unresolvedEntity",
+                name, publicId, systemId, base));
     }
 
 
     @Override
-    public InputSource getExternalSubset(String name, String baseURI) throws SAXException, IOException {
+    public InputSource getExternalSubset(String name, String baseURI)
+            throws SAXException, IOException {
         return null;
     }
 }
