@@ -17,9 +17,12 @@
 package org.apache.tomcat.util.descriptor.web;
 
 
+
 /**
- * Representation of an application environment entry, as represented in an <code>&lt;env-entry&gt;</code> element in
- * the deployment descriptor.
+ * Representation of an application environment entry, as represented in
+ * an <code>&lt;env-entry&gt;</code> element in the deployment descriptor.
+ *
+ * @author Craig R. McClanahan
  */
 public class ContextEnvironment extends ResourceBase {
 
@@ -30,7 +33,8 @@ public class ContextEnvironment extends ResourceBase {
 
 
     /**
-     * Does this environment entry allow overrides by the application deployment descriptor?
+     * Does this environment entry allow overrides by the application
+     * deployment descriptor?
      */
     private boolean override = true;
 
@@ -115,9 +119,12 @@ public class ContextEnvironment extends ResourceBase {
             return false;
         }
         if (value == null) {
-            return other.value == null;
-        } else {
-            return value.equals(other.value);
+            if (other.value != null) {
+                return false;
+            }
+        } else if (!value.equals(other.value)) {
+            return false;
         }
+        return true;
     }
 }
