@@ -801,9 +801,9 @@ final class SetAuthConstraintRule extends Rule {
         SecurityConstraint securityConstraint =
             (SecurityConstraint) digester.peek();
         securityConstraint.setAuthConstraint(true);
-        if (digester.getLogger().isDebugEnabled()) {
+        if (digester.getLogger().isTraceEnabled()) {
             digester.getLogger()
-               .debug("Calling SecurityConstraint.setAuthConstraint(true)");
+               .trace("Calling SecurityConstraint.setAuthConstraint(true)");
         }
 
         StringBuilder code = digester.getGeneratedCode();
@@ -832,8 +832,8 @@ final class SetDistributableRule extends Rule {
         throws Exception {
         WebXml webXml = (WebXml) digester.peek();
         webXml.setDistributable(true);
-        if (digester.getLogger().isDebugEnabled()) {
-            digester.getLogger().debug
+        if (digester.getLogger().isTraceEnabled()) {
+            digester.getLogger().trace
                (webXml.getClass().getName() + ".setDistributable(true)");
         }
 
@@ -862,8 +862,8 @@ final class SetDenyUncoveredHttpMethodsRule extends Rule {
         throws Exception {
         WebXml webXml = (WebXml) digester.peek();
         webXml.setDenyUncoveredHttpMethods(true);
-        if (digester.getLogger().isDebugEnabled()) {
-            digester.getLogger().debug(webXml.getClass().getName() +
+        if (digester.getLogger().isTraceEnabled()) {
+            digester.getLogger().trace(webXml.getClass().getName() +
                     ".setDenyUncoveredHttpMethods(true)");
         }
 
@@ -904,14 +904,13 @@ final class SetPublicIdRule extends Rule {
         try {
             m = top.getClass().getMethod(method, paramClasses);
         } catch (NoSuchMethodException e) {
-            digester.getLogger().error("Can't find method " + method + " in "
-                                       + top + " CLASS " + top.getClass());
+            digester.getLogger().error(sm.getString("webRuleSet.noMethod", method, top, top.getClass()));
             return;
         }
 
         m.invoke(top, (Object [])paramValues);
-        if (digester.getLogger().isDebugEnabled()) {
-            digester.getLogger().debug("" + top.getClass().getName() + "."
+        if (digester.getLogger().isTraceEnabled()) {
+            digester.getLogger().trace("" + top.getClass().getName() + "."
                                        + method + "(" + paramValues[0] + ")");
         }
 
@@ -943,8 +942,8 @@ final class ServletDefCreateRule extends Rule {
         throws Exception {
         ServletDef servletDef = new ServletDef();
         digester.push(servletDef);
-        if (digester.getLogger().isDebugEnabled()) {
-            digester.getLogger().debug("new " + servletDef.getClass().getName());
+        if (digester.getLogger().isTraceEnabled()) {
+            digester.getLogger().trace("new " + servletDef.getClass().getName());
         }
 
         StringBuilder code = digester.getGeneratedCode();
@@ -959,8 +958,8 @@ final class ServletDefCreateRule extends Rule {
     public void end(String namespace, String name)
         throws Exception {
         ServletDef servletDef = (ServletDef) digester.pop();
-        if (digester.getLogger().isDebugEnabled()) {
-            digester.getLogger().debug("pop " + servletDef.getClass().getName());
+        if (digester.getLogger().isTraceEnabled()) {
+            digester.getLogger().trace("pop " + servletDef.getClass().getName());
         }
 
         StringBuilder code = digester.getGeneratedCode();
@@ -1141,8 +1140,8 @@ final class IgnoreAnnotationsRule extends Rule {
         } else {
             value = null;
         }
-        if (digester.getLogger().isDebugEnabled()) {
-            digester.getLogger().debug
+        if (digester.getLogger().isTraceEnabled()) {
+            digester.getLogger().trace
                 (webXml.getClass().getName() + ".setMetadataComplete( " +
                         webXml.isMetadataComplete() + ")");
         }
@@ -1175,8 +1174,8 @@ final class VersionRule extends Rule {
         WebXml webXml = (WebXml) digester.peek(digester.getCount() - 1);
         webXml.setVersion(attributes.getValue("version"));
 
-        if (digester.getLogger().isDebugEnabled()) {
-            digester.getLogger().debug
+        if (digester.getLogger().isTraceEnabled()) {
+            digester.getLogger().trace
                 (webXml.getClass().getName() + ".setVersion( " +
                         webXml.getVersion() + ")");
         }
@@ -1257,8 +1256,8 @@ final class AbsoluteOrderingRule extends Rule {
             isAbsoluteOrderingSet = true;
             WebXml webXml = (WebXml) digester.peek();
             webXml.createAbsoluteOrdering();
-            if (digester.getLogger().isDebugEnabled()) {
-                digester.getLogger().debug(
+            if (digester.getLogger().isTraceEnabled()) {
+                digester.getLogger().trace(
                         webXml.getClass().getName() + ".setAbsoluteOrdering()");
             }
 
@@ -1498,8 +1497,8 @@ final class SetOverrideRule extends Rule {
     public void begin(String namespace, String name, Attributes attributes) throws Exception {
         ContextEnvironment envEntry = (ContextEnvironment) digester.peek();
         envEntry.setOverride(false);
-        if (digester.getLogger().isDebugEnabled()) {
-            digester.getLogger().debug(envEntry.getClass().getName() + ".setOverride(false)");
+        if (digester.getLogger().isTraceEnabled()) {
+            digester.getLogger().trace(envEntry.getClass().getName() + ".setOverride(false)");
         }
 
         StringBuilder code = digester.getGeneratedCode();
